<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Ws_model extends CI_Model{

/*default functions*/
public function common_fetch($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','desc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_fetch_select($table, $where = [], $select = '*', $integerFields = []) {
    $this->db->select($select);
    $this->db->from($table);
    
    if (!empty($where)) {
        $this->db->where($where);
    }
    $this->db->order_by('id','desc');
    $query = $this->db->get();
    
    if ($query->num_rows() > 0) {
        $result = $query->result_array();
        
        // Type-cast requested fields to integer
        if (!empty($integerFields)) {
            foreach ($result as &$row) {
                foreach ($integerFields as $field) {
                    if (isset($row[$field])) {
                        $row[$field] = (int) $row[$field];
                    }
                }
            }
            unset($row);
        }
        
        return $result;
    } else {
        return [];
    }
}
public function common_fetch_asc($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','asc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_insert($table,$data){	
	$this->db->insert($table,$data);
	$id = $this->db->insert_id();
	return $id;
}
public function common_update($table,$data,$where){
	$this->db->where($where);
	$this->db->update($table,$data);
}
public function common_delete($table,$where){
	$this->db->where($where);
	$this->db->delete($table);
}
public function common_fetch_rows($table,$where){
	$this->db->where($where);	
	$query = $this->db->get($table);
	return $query->num_rows();
}
// In your Ws_model.php
public function is_exists($table, $where = []) {
    $this->db->from($table);
    if (!empty($where)) {
        $this->db->where($where);
    }
    $query = $this->db->limit(1)->get();
    return $query->num_rows() > 0;
}
/*default functions*/

/*home_page*/
public function ambulance_bookings_history_active($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id, b.date, b.mobile,b.name,b.address_id,b.ambulance_driver_id,b.trip_status,u.hno,u.colony,u.pincode,u.state,u.landmark,u.address_type,u.default_address,u.lat,u.lon,IFNULL(a.name, "") AS ambulance_driver_name');

    $this->db->from('ambulance_bookings b');
    $this->db->where('b.ambulance_driver_id', $user_id);
    $this->db->where('b.booking_status', 'booked');
    
    // accept_status = 'accepted' OR ''
    $this->db->group_start();
    $this->db->where('b.accept_status', 'accepted');
    $this->db->or_where('b.accept_status', '');
    $this->db->group_end();
    
    $this->db->join('user_addresses u','u.id=b.address_id','left');
    $this->db->join('ambulance_drivers a','a.id=b.ambulance_driver_id','left');
    // Avoid duplicates in case of joins
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'ambulance_driver_name' => $row['ambulance_driver_name'],
            'trip_status'           => $row['trip_status'],
            'address_id'            => intval($row['address_id']),
            'hno'                   => $row['hno'],
            'colony'                => $row['colony'],
            'pincode'               => intval($row['pincode']),
            'state'                 => $row['state'],
            'landmark'              => $row['landmark'],
            'address_type'          => $row['address_type'],
            'default_address'       => intval($row['default_address']),
            'lat'                   => $row['lat'],
            'lon'                   => $row['lon']
        ];
    }, $result);
}
public function ambulance_bookings_history_active_rows($user_id){
    $this->db->from('ambulance_bookings b');
    $this->db->where('b.ambulance_driver_id', $user_id);
    $this->db->where('b.booking_status', 'booked');
    return $this->db->count_all_results();
}
public function ambulance_bookings_history_completed($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id, b.date, b.mobile,b.name,b.address_id,b.trip_status,u.hno,u.colony,u.pincode,u.state,u.landmark,u.address_type,u.default_address,u.lat,u.lon,IFNULL(a.name, "") AS ambulance_driver_name');

    $this->db->from('ambulance_bookings b');
    $this->db->where('b.ambulance_driver_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    
    $this->db->join('user_addresses u','u.id=b.address_id','left');
    $this->db->join('ambulance_drivers a','a.id=b.ambulance_driver_id','left');
    // Avoid duplicates in case of joins
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'ambulance_driver_name' => $row['ambulance_driver_name'],
            'trip_status'           => $row['trip_status'],
            'address_id'            => intval($row['address_id']),
            'hno'                   => $row['hno'],
            'colony'                => $row['colony'],
            'pincode'               => intval($row['pincode']),
            'state'                 => $row['state'],
            'landmark'              => $row['landmark'],
            'address_type'          => $row['address_type'],
            'default_address'       => intval($row['default_address']),
            'lat'                   => $row['lat'],
            'lon'                   => $row['lon']
        ];
    }, $result);
}
public function ambulance_bookings_history_completed_rows($user_id){
    $this->db->from('ambulance_bookings b');
    $this->db->where('b.ambulance_driver_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    return $this->db->count_all_results();
}
/*home_page*/

/*hamburger*/
public function single_ambulance_booking_details($booking_id){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id, b.date, b.mobile,b.name,b.address_id,b.trip_status,u.hno,u.colony,u.pincode,u.state,u.landmark,u.address_type,u.default_address,u.lat,u.lon,IFNULL(a.name, "") AS ambulance_driver_name,a.mobile as driver_mobile,IFNULL(a.vehicle_number, "") AS vehicle_number,IFNULL(a.image, "") AS image');

    $this->db->from('ambulance_bookings b');
    $this->db->where('b.booking_id', $booking_id);
    
    $this->db->join('user_addresses u','u.id=b.address_id','left');
    $this->db->join('ambulance_drivers a','a.id=b.ambulance_driver_id','left');
    // Avoid duplicates in case of joins
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'ambulance_driver_name' => $row['ambulance_driver_name'],
            'driver_mobile'         => intval($row['driver_mobile']),
            'vehicle_number'        => $row['vehicle_number'],
            'image'                 => $row['image'],
            'trip_status'           => $row['trip_status'],
            'address_id'            => intval($row['address_id']),
            'hno'                   => $row['hno'],
            'colony'                => $row['colony'],
            'pincode'               => intval($row['pincode']),
            'state'                 => $row['state'],
            'landmark'              => $row['landmark'],
            'address_type'          => $row['address_type'],
            'default_address'       => intval($row['default_address']),
            'lat'                   => $row['lat'],
            'lon'                   => $row['lon']
        ];
    }, $result);
}
/*hamburger*/


}
?>