<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Ws_model extends CI_Model{

/*default functions*/
public function common_fetch($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','desc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_fetch_select($table, $where = [], $select = '*', $integerFields = []) {
    $this->db->select($select);
    $this->db->from($table);
    
    if (!empty($where)) {
        $this->db->where($where);
    }
    $this->db->order_by('id','desc');
    $query = $this->db->get();
    
    if ($query->num_rows() > 0) {
        $result = $query->result_array();
        
        // Type-cast requested fields to integer
        if (!empty($integerFields)) {
            foreach ($result as &$row) {
                foreach ($integerFields as $field) {
                    if (isset($row[$field])) {
                        $row[$field] = (int) $row[$field];
                    }
                }
            }
            unset($row);
        }
        
        return $result;
    } else {
        return [];
    }
}
public function common_fetch_asc($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','asc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_insert($table,$data){	
	$this->db->insert($table,$data);
	$id = $this->db->insert_id();
	return $id;
}
public function common_update($table,$data,$where){
	$this->db->where($where);
	$this->db->update($table,$data);
}
public function common_delete($table,$where){
	$this->db->where($where);
	$this->db->delete($table);
}
public function common_fetch_rows($table,$where){
	$this->db->where($where);	
	$query = $this->db->get($table);
	return $query->num_rows();
}
// In your Ws_model.php
public function is_exists($table, $where = []){
    $this->db->from($table);
    if (!empty($where)) {
        $this->db->where($where);
    }
    $query = $this->db->limit(1)->get();
    return $query->num_rows() > 0;
}
/*default functions*/

/*doctor*/
public function hospital_specializations($user_id){
    $this->db->select('mds.id,mds.speciality_id,s.name')->from('main_data_specialities mds');
    $this->db->where(['mds.main_data_id' => $user_id, 'mds.status' => 1, 'mds.delete_status' => 1]);
    $this->db->join('specialities s','s.id=mds.speciality_id','left');
    $this->db->order_by('mds.id','desc');
    $query = $this->db->get();
    $result = $query->result_array();
    
    // Process the results
    return array_map(function ($row) {
        
        return [
            'id'                => intval($row['id']),
            'speciality_id'     => intval($row['speciality_id']),
            'name'              => $row['name']
        ];
    }, $result);
    
}
public function get_doctor_booked_slots($doctor_id,$date){
    $this->db->select('id as slot_id, time, date, booking_status');
    $this->db->from('doctor_slots');
    $this->db->where('doctor_id', $doctor_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1); // Ensure only active slots are fetched
    $this->db->where('delete_status', 1); // Ensure only non-deleted slots are fetched

    $results = $this->db->get()->result_array();

    // Normalize time format
    foreach ($results as &$row) {
        $row['time'] = date('h:i A', strtotime($row['time']));
    }

    return $results;
}
public function get_doctors($user_id, $limit, $offset){
    $this->db->select('
        doctors.*, 
        IFNULL(rating_data.total_rating, 0) AS total_rating, 
        IFNULL(rating_data.total_reviews, 0) AS total_reviews,
        main_data.name as hospital_name,
        main_data.location, 
        GROUP_CONCAT(DISTINCT md.name ORDER BY md.name SEPARATOR ", ") AS qualification, 
        s.name as specialization,
        IFNULL(consultation_data.consultations, 0) AS consultations
    ');
    
    $this->db->from('doctors');

    // Where conditions
    $this->db->where([
        //'doctors.cat_id' => $cat_id,
        'doctors.main_data_id' => $user_id,
        'doctors.status' => 1,
        'doctors.delete_status' => 1
    ]);

    // Correct joins
    $this->db->join('main_data', 'main_data.id = doctors.main_data_id', 'left');
    $this->db->join('medical_degrees md', 'FIND_IN_SET(md.id, doctors.qualification)', 'left');
    $this->db->join('specialities s', 's.id = doctors.speciality_id', 'left');

    // Subquery join for ratings
    $this->db->join(
        '(SELECT doctor_id, cat_id, main_data_id, SUM(rating) as total_rating, COUNT(id) as total_reviews 
          FROM doctor_ratings 
          GROUP BY doctor_id, cat_id, main_data_id) rating_data',
        'rating_data.cat_id = doctors.cat_id 
         AND rating_data.main_data_id = doctors.main_data_id 
         AND rating_data.doctor_id = doctors.id',
        'left'
    );

    // Subquery join for consultations
    $this->db->join(
        '(SELECT doctor_id, COUNT(id) as consultations 
          FROM doctor_bookings 
          GROUP BY doctor_id) consultation_data',
        'consultation_data.doctor_id = doctors.id',
        'left'
    );

    $this->db->group_by('doctors.id');
    $this->db->order_by('doctors.id', 'desc');
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array(); 

    // Process the results
    return array_map(function ($row) {
        $total_rating = floatval($row['total_rating']);
        $total_reviews = intval($row['total_reviews']);
        $average_rating = ($total_reviews > 0) ? round($total_rating / $total_reviews, 1) : 0.0;

        return [
            'id'                => intval($row['id']),
            'unique_id'         => $row['unique_id'],
            'cat_id'            => intval($row['cat_id']),
            'sub_cat_id'        => intval($row['sub_cat_id']),
            'sub_sub_cat_id'    => intval($row['sub_sub_cat_id']),
            'main_data_id'      => intval($row['main_data_id']),
            'speciality_id'     => intval($row['speciality_id']),
            'name'              => $row['name'],
            'image'             => $row['image'],
            'qualification'     => $row['qualification'],
            'specialization'    => $row['specialization'],
            'hospital_name'     => $row['hospital_name'],
            'exp'               => $row['exp'],
            'description'       => $row['description'],
            'offline_fee'       => intval($row['offline_fee']),
            'online_fee'        => intval($row['online_fee']),
            //'consult_type'      => $row['consult_type'],
            'rating'            => $average_rating,
            'total_reviews'     => $total_reviews,
            'consultations'     => intval($row['consultations']),
            'location'          => $row['location'],
            'availability'      => intval($row['availability']),
        ];
    }, $result);
}
public function get_doctors_rows($user_id){
    $this->db->from('doctors');
    $this->db->where([
        //'doctors.cat_id' => $cat_id,
        'doctors.main_data_id' => $user_id,
        'doctors.status' => 1,
        'doctors.delete_status' => 1
    ]);
    return $this->db->count_all_results();
}
public function get_single_doctor($user_id, $doctor_id){
    $this->db->select('
        doctors.*, 
        IFNULL(rating_data.total_rating, 0) AS total_rating, 
        IFNULL(rating_data.total_reviews, 0) AS total_reviews,
        main_data.name as hospital_name,
        main_data.location, 
        GROUP_CONCAT(DISTINCT md.name ORDER BY md.name SEPARATOR ", ") AS qualification_name, 
        s.name as specialization,
        IFNULL(consultation_data.consultations, 0) AS consultations
    ');
    
    $this->db->from('doctors');

    // Where conditions
    $this->db->where([
        //'doctors.cat_id' => $cat_id,
        'doctors.main_data_id' => $user_id,
        'doctors.id' => $doctor_id,
        'doctors.status' => 1,
        'doctors.delete_status' => 1
    ]);

    // Correct joins
    $this->db->join('main_data', 'main_data.id = doctors.main_data_id', 'left');
    $this->db->join('medical_degrees md', 'FIND_IN_SET(md.id, doctors.qualification)', 'left');
    $this->db->join('specialities s', 's.id = doctors.speciality_id', 'left');

    // Subquery join for ratings
    $this->db->join(
        '(SELECT doctor_id, cat_id, main_data_id, SUM(rating) as total_rating, COUNT(id) as total_reviews 
          FROM doctor_ratings 
          GROUP BY doctor_id, cat_id, main_data_id) rating_data',
        'rating_data.cat_id = doctors.cat_id 
         AND rating_data.main_data_id = doctors.main_data_id 
         AND rating_data.doctor_id = doctors.id',
        'left'
    );

    // Subquery join for consultations
    $this->db->join(
        '(SELECT doctor_id, COUNT(id) as consultations 
          FROM doctor_bookings 
          GROUP BY doctor_id) consultation_data',
        'consultation_data.doctor_id = doctors.id',
        'left'
    );

    $this->db->group_by('doctors.id');
    $this->db->order_by('doctors.id', 'desc');
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array(); 

    // Process the results
    return array_map(function ($row) {
        $total_rating = floatval($row['total_rating']);
        $total_reviews = intval($row['total_reviews']);
        $average_rating = ($total_reviews > 0) ? round($total_rating / $total_reviews, 1) : 0.0;

        return [
            'id'                => intval($row['id']),
            'unique_id'         => $row['unique_id'],
            'cat_id'            => intval($row['cat_id']),
            'sub_cat_id'        => intval($row['sub_cat_id']),
            'sub_sub_cat_id'    => intval($row['sub_sub_cat_id']),
            'main_data_id'      => intval($row['main_data_id']),
            'speciality_id'     => intval($row['speciality_id']),
            'name'              => $row['name'],
            'mobile'            => intval($row['mobile']),
            'image'             => $row['image'],
            'qualification_ids' => $row['qualification'],
            'qualification'     => $row['qualification_name'],
            'specialization'    => $row['specialization'],
            'hospital_name'     => $row['hospital_name'],
            'exp'               => $row['exp'],
            'description'       => $row['description'],
            'offline_fee'       => intval($row['offline_fee']),
            'online_fee'        => intval($row['online_fee']),
            'consult_type'      => $row['consult_type'],
            'rating'            => $average_rating,
            'total_reviews'     => $total_reviews,
            'consultations'     => intval($row['consultations']),
            'location'          => $row['location'],
            'availability'      => intval($row['availability']),
        ];
    }, $result);
}
/*doctor*/

/*home_page*/

/*pharmacy_bookings*/
public function get_product_orders($user_id){
    $this->db->select('pb.id, pb.booking_id, pb.created_on, pb.order_type, pb.booking_type, pb.accept_status, pbi.id AS product_id, pbi.name AS product_name, pbi.image, pbi.price, pbi.original_price');
    $this->db->from('hospital_pharmacy_product_bookings pb');
    $this->db->join('hospital_pharmacy_booked_products pbi', 'pbi.booking_id = pb.booking_id', 'left');
    
    $this->db->where('pb.main_data_id', $user_id);
    
    // booking_status = 'booked' OR 'picked up'
    $this->db->group_start();
    $this->db->where('pb.booking_status', 'booked');
    $this->db->or_where('pb.booking_status', 'pickedup');
    $this->db->group_end();

    // accept_status = 'accepted' OR ''
    $this->db->group_start();
    $this->db->where('pb.accept_status', 'accepted');
    $this->db->or_where('pb.accept_status', '');
    $this->db->group_end();

    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'           => $row->id,
                'booking_id'   => $row->booking_id,
                'order_type'   => $row->order_type,
                'booking_type' => $row->booking_type,
                'accept_status'=> $row->accept_status,
                'created_on'   => $row->created_on,
                'image'        => "",
                'products'     => []
            ];
        }
        $result[$id]['products'][] = [
            'product_name'      => $row->product_name,
            'image'             => $row->image,
            'price'             => $row->price,
            'original_price'    => $row->original_price
        ];
    }

    return array_values($result);
}
public function get_prescription_orders($user_id){
    $this->db->select('id, booking_id, order_type, created_on,booking_type,image,accept_status');
    $this->db->from('hospital_pharmacy_medicine_orders');
    $this->db->where(['main_data_id' => $user_id]);
    
    // booking_status = 'booked' OR 'picked up'
    $this->db->group_start();
    $this->db->where('booking_status', 'booked');
    $this->db->or_where('booking_status', 'pickedup');
    $this->db->group_end();
    
    // Add accept_status = 'accepted' OR accept_status = ''
    $this->db->group_start();
    $this->db->where('accept_status', 'accepted');
    $this->db->or_where('accept_status', '');
    $this->db->group_end();
    $this->db->order_by('created_on', 'DESC');

    $query = $this->db->get();
    $orders = $query->result();

    return $orders;
}
public function pharmacy_combined_orders($user_id, $limit, $offset){
    $product_orders = $this->get_product_orders($user_id);
    $prescription_orders = $this->get_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    usort($combined, function($a, $b) {
        return strtotime($b->created_on ?? $b['created_on']) - strtotime($a->created_on ?? $a['created_on']);
    });

    // Pagination manually
    $paged_orders = array_slice($combined, $offset, $limit);

    return [
        'orders' => $paged_orders,
        'total_orders' => count($combined),
        'limit' => $limit,
        'offset' => $offset
    ];
}
public function get_pharmacy_single_product_orders($booking_id){
    $this->db->select('pb.id,pb.booking_id, pb.created_on, pb.order_type, pb.user_id, pb.main_data_id, pb.cat_id, pb.address_id, pb.mobile, pb.name, pb.fee, pb.consultation_fee, pb.coupon_id,pb.coupon_name,pb.coupon_percentage,pb.coupon_discount,pb.payment_type,pb.booking_status,pb.order_type,pb.booking_type,pb.accept_status, pbi.id AS product_id, pbi.name AS product_name, pbi.image,u.image as user_image');
    $this->db->from('hospital_pharmacy_product_bookings pb');
    $this->db->join('hospital_pharmacy_booked_products pbi', 'pbi.booking_id = pb.booking_id', 'left');
    //$this->db->join('hospital_pharmacy_products p', 'p.id = pbi.product_id', 'left');
    $this->db->join('users u', 'u.id = pb.user_id', 'left');
    $this->db->where('pb.booking_id', $booking_id);
    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    // Group by booking ID to avoid duplication
    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'                => intval($row->id),
                'booking_id'        => $row->booking_id,
                'order_type'        => $row->order_type,
                'user_id'           => intval($row->user_id),
                'main_data_id'      => intval($row->main_data_id),
                'cat_id'            => intval($row->cat_id),
                'address_id'        => intval($row->address_id),
                'name'              => $row->name,
                'mobile'            => intval($row->mobile),
                'user_image'        => $row->user_image,
                'fee'               => intval($row->fee),
                'consultation_fee'  => intval($row->consultation_fee),
                'coupon_id'         => intval($row->coupon_id),
                'coupon_percentage' => intval($row->coupon_percentage),
                'coupon_discount'   => intval($row->coupon_discount),
                'payment_type'      => $row->payment_type,
                'order_type'        => $row->order_type,
                'booking_type'      => $row->booking_type,
                'booking_status'    => $row->booking_status,
                'accept_status'     => $row->accept_status,
                'created_on'        => $row->created_on,
                'image'             => '',
                'products'          => []
            ];
        }
        $result[$id]['products'][] = [
            'product_name' => $row->product_name,
            'image' => $row->image
        ];
    }

    return array_values($result);
}
public function get_pharmacy_single_medicine_orders($booking_id){
    $this->db->select('pb.id,pb.booking_id, pb.created_on, pb.order_type, pb.user_id, pb.main_data_id, pb.address_id, pb.mobile, pb.name,pb.booking_status,pb.order_type,pb.booking_type, pb.accept_status,pb.image,u.image as user_image');
    $this->db->from('hospital_pharmacy_medicine_orders pb');
    $this->db->join('users u', 'u.id = pb.user_id', 'left');
    $this->db->where('pb.booking_id', $booking_id);
    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    // Group by booking ID to avoid duplication
    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'                => intval($row->id),
                'booking_id'        => $row->booking_id,
                'image'             => $row->image,
                'order_type'        => $row->order_type,
                'user_id'           => intval($row->user_id),
                'main_data_id'      => intval($row->main_data_id),
                'address_id'        => intval($row->address_id),
                'name'              => $row->name,
                'mobile'            => intval($row->mobile),
                'user_image'        => $row->user_image,
                'booking_type'      => $row->booking_type,
                'booking_status'    => $row->booking_status,
                'accept_status'     => $row->accept_status,
                'created_on'        => $row->created_on
            ];
        }
    }

    return array_values($result);
}
public function get_pharmacy_products($user_id, $cat_id, $limit, $offset){
    $this->db->select('
        pp.id,
        pp.main_data_id,
        pp.cat_id,
        pp.name,
        pp.image,
        pp.price,
        pp.discount_price
    ');
    $this->db->from('hospital_pharmacy_products pp');
    $this->db->where([ 
        'pp.main_data_id' => $user_id,
        'pp.cat_id'       => $cat_id,
        'pp.status'       => 1,
        'pp.delete_status'=> 1
    ]);
    $this->db->order_by('pp.id', 'desc');
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    return array_map(function ($row) {
        return [
            'id'             => intval($row['id']),
            'main_data_id'   => intval($row['main_data_id']),
            'cat_id'         => intval($row['cat_id']),
            'name'           => $row['name'],
            'image'          => $row['image'],
            'price'          => intval($row['price']),
            'discount_price' => intval($row['discount_price'])
        ];
    }, $result);
}
public function get_pharmacy_products_rows($user_id,$cat_id){
    $this->db->where(['main_data_id' => $user_id,'cat_id' => $cat_id,'status' => 1,'delete_status' => 1]);
    $this->db->order_by('id','desc');
    $query = $this->db->get('hospital_pharmacy_products');
    $result = $query->num_rows();
    return $result;
}
public function get_completed_product_orders($user_id){
    $this->db->select('pb.id, pb.booking_id, pb.created_on, pb.order_type, pb.booking_type,pb.accept_status, pbi.id AS product_id, pbi.name AS product_name, pbi.image, pbi.price, pbi.original_price');
    $this->db->from('hospital_pharmacy_product_bookings pb');
    $this->db->join('hospital_pharmacy_booked_products pbi', 'pbi.booking_id = pb.booking_id', 'left');
    //$this->db->join('hospital_pharmacy_products p', 'p.id = pbi.product_id', 'left');
    $this->db->where('pb.main_data_id', $user_id);
    $this->db->where('pb.booking_status', 'completed');

    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'           => $row->id,
                'booking_id'   => $row->booking_id,
                'order_type'   => $row->order_type,
                'booking_type' => $row->booking_type,
                'accept_status'=> $row->accept_status,
                'created_on'   => $row->created_on,
                'image'        => "",
                'products'     => []
            ];
        }
        $result[$id]['products'][] = [
            'product_name'      => $row->product_name,
            'image'             => $row->image,
            'price'             => $row->price,
            'original_price'    => $row->original_price
        ];
    }

    return array_values($result);
}
public function get_completed_prescription_orders($user_id){
    $this->db->select('id, booking_id, order_type, created_on,booking_type,image,accept_status');
    $this->db->from('hospital_pharmacy_medicine_orders');
    $this->db->where(['main_data_id' => $user_id,'booking_status' => 'completed']);
    $this->db->order_by('created_on', 'DESC');

    $query = $this->db->get();
    $orders = $query->result();

    return $orders;
}
public function pharmacy_completed_combined_orders($user_id, $limit, $offset){
    $product_orders = $this->get_completed_product_orders($user_id);
    $prescription_orders = $this->get_completed_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    usort($combined, function($a, $b) {
        return strtotime($b->created_on ?? $b['created_on']) - strtotime($a->created_on ?? $a['created_on']);
    });

    // Pagination manually
    $paged_orders = array_slice($combined, $offset, $limit);

    return [
        'orders' => $paged_orders,
        'total_orders' => count($combined),
        'limit' => $limit,
        'offset' => $offset
    ];
}
/*pharmacy_bookings*/

/*diagnostic_bookings*/
public function get_hospital_diagnostic_bookings($user_id){
    $this->db->select('
        db.id,
        db.booking_id,
        db.created_on,
        db.user_id,
        db.main_data_id,
        db.booking_status,
        db.booking_type,
        (SELECT name FROM hospital_diagnostic_booking_packages hdbp WHERE hdbp.booking_id = db.booking_id LIMIT 1) AS name,
        db.count,
        db.image,
        db.mobile,
        db.accept_status,
        db.slot_id,
        db.date,
        db.time,
        (
            (SELECT COUNT(*) FROM hospital_diagnostic_booking_tests hdbt WHERE hdbt.booking_id = db.booking_id) +
            (SELECT COUNT(*) FROM hospital_diagnostic_booking_subtests hdbst WHERE hdbst.booking_id = db.booking_id)
        ) AS total_test_count
    ');
    $this->db->from('hospital_diagnostic_bookings db');
    $this->db->where('db.main_data_id', $user_id);
    $this->db->where('db.booking_status', 'booked');
    $this->db->group_start();
    $this->db->where('db.accept_status', 'accepted');
    $this->db->or_where('db.accept_status', '');
    $this->db->group_end();
    $this->db->join('main_data d', 'd.id=db.main_data_id', 'left');
    $this->db->order_by('db.id', 'DESC');


    $query = $this->db->get();
    $result = $query->result_array();

    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id' => $row['booking_id'],
            'created_on' => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => intval($row['count']),
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type' => $row['booking_type'],
            'total_test_count' => intval($row['total_test_count']),
            'accept_status' => $row['accept_status'],
            'slot_id'       => intval($row['slot_id']),
            'date'          => $row['date'],
            'time'          => $row['time'],
        ];
    }, $result);
}
public function get_hospital_diagnostic_prescription_orders($user_id){
    $this->db->select('dpb.id, dpb.booking_id, dpb.created_on,dpb.user_id,dpb.main_data_id,dpb.image,dpb.accept_status,dpb.booking_status,dpb.booking_type,dpb.image,dpb.name,dpb.mobile,dpb.accept_status');
    $this->db->from('hospital_diagnostic_prescription_bookings dpb');
    $this->db->where(['main_data_id' => $user_id,'booking_status' => 'booked']);
    // Add accept_status = 'accepted' OR accept_status = ''
    $this->db->group_start();
    $this->db->where('accept_status', 'accepted');
    $this->db->or_where('accept_status', '');
    $this->db->group_end();
    //$this->db->join('main_data d','d.id=dpb.main_data_id','left');
    $this->db->order_by('dpb.id', 'DESC');

    $query = $this->db->get();
    $orders = $query->result_array();
    
    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id'    => $row['booking_id'],
            'created_on'    => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => 0,
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type'      => $row['booking_type'],
            'total_test_count' => 0,
            'accept_status'      => $row['accept_status'],
            'slot_id'       => 0,
            'date'          => '',
            'time'          => '',
        ];
    }, $orders);
}
public function hospital_diagnostic_combined_orders($user_id, $limit, $offset,$page){
    $product_orders = $this->get_hospital_diagnostic_bookings($user_id);
    $prescription_orders = $this->get_hospital_diagnostic_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    if(!empty($combined)){
        /*usort($combined, function($a, $b) {
            //return strtotime($b->id ?? $b['id']) - strtotime($a->created_on ?? $a['created_on']);
        });*/
    
        // Pagination manually
        $paged_orders = array_slice($combined, $offset, $limit);
    
        $total_pages   = ceil(count($combined) / $limit);
        $pages = [];
    
        for ($t = 1; $t <= $total_pages; $t++) {
            $pages[] = ['page' => $t];
        }
    
        return [
            'history' => $paged_orders,
            'pagination' => [
                'total_pages'  => $pages,
                'current_page' => $page,
                'limit'        => $limit
            ]
        ];
    }else{
        return [];
    }
}
public function get_diagnostic_slots($main_data_id, $date){
    $today = date('Y-m-d');
    $current_time = date('H:i'); // current time in 24-hour format

    $this->db->select('id, time, session, booking_status, date');
    $this->db->from('hospital_diagnostic_slots');
    $this->db->where('main_data_id', $main_data_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1);
    $this->db->where('delete_status', 1);

    // If today, filter out past time slots (we do this in PHP after query)
    $this->db->order_by('id', 'ASC'); // Use ID or leave unordered (will sort in PHP)

    $query = $this->db->get();
    $results = $query->result_array();

    $slots = ['morning' => [], 'afternoon' => [], 'evening' => []];

    foreach ($results as $row) {
        $row['id'] = (int)$row['id'];
        $row['format_date'] = date('d M Y', strtotime($row['date']));

        // Convert time (12-hour) to 24-hour for sorting & filtering
        $slot_time_24hr = date('H:i', strtotime($row['time']));

        // Filter out past slots for today's date
        if ($date == $today && $slot_time_24hr < $current_time) {
            continue;
        }

        // Assign session
        if ($slot_time_24hr >= '05:00' && $slot_time_24hr < '12:00') {
            $slots['morning'][] = $row;
        } elseif ($slot_time_24hr >= '12:00' && $slot_time_24hr < '16:00') {
            $slots['afternoon'][] = $row;
        } else {
            $slots['evening'][] = $row;
        }
    }

    // Sort each session manually by slot time
    foreach ($slots as &$session) {
        usort($session, function ($a, $b) {
            return strtotime($a['time']) - strtotime($b['time']);
        });
    }

    return ['slots' => $slots];
}
public function get_hospital_diagnostic_completed_bookings($user_id){
    $this->db->select('
        db.id,
        db.booking_id,
        db.created_on,
        db.user_id,
        db.main_data_id,
        db.booking_status,
        db.booking_type,
        db.count,
        db.image,
        db.mobile,
        db.slot_id,
        db.date,
        db.time,
        (
            SELECT name 
            FROM hospital_diagnostic_booking_packages hdbp 
            WHERE hdbp.booking_id = db.booking_id 
            LIMIT 1
        ) AS name,
        (
            (SELECT COUNT(*) FROM hospital_diagnostic_booking_tests hdbt WHERE hdbt.booking_id = db.booking_id) +
            (SELECT COUNT(*) FROM hospital_diagnostic_booking_subtests hdbst WHERE hdbst.booking_id = db.booking_id)
        ) AS total_test_count
    ');
    $this->db->from('hospital_diagnostic_bookings db');
    $this->db->where('db.main_data_id', $user_id);
    $this->db->where('db.booking_status', 'completed');
    $this->db->join('main_data d','d.id=db.main_data_id','left');
    $this->db->order_by('db.id', 'DESC');

    $query = $this->db->get();
    $result = $query->result_array();

    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id' => $row['booking_id'],
            'created_on' => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => intval($row['count']),
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type' => $row['booking_type'],
            'total_test_count' => intval($row['total_test_count']),
            'slot_id' => intval($row['slot_id']),
            'date' => $row['date'],
            'time' => $row['time'],
        ];
    }, $result);
}
public function get_hospital_diagnostic_completed_prescription_orders($user_id){
    $this->db->select('dpb.id, dpb.booking_id, dpb.created_on,dpb.user_id,dpb.main_data_id,dpb.image,dpb.accept_status,dpb.booking_status,dpb.booking_type,dpb.mobile,dpb.name');
    $this->db->from('hospital_diagnostic_prescription_bookings dpb');
    $this->db->where(['main_data_id' => $user_id,'booking_status' => 'completed']);
    // Add accept_status = 'accepted' OR accept_status = ''
    
    //$this->db->join('main_data d','d.id=dpb.main_data_id','left');
    $this->db->order_by('dpb.id', 'DESC');

    $query = $this->db->get();
    $orders = $query->result_array();
    
    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id'    => $row['booking_id'],
            'created_on'    => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => 0,
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type'      => $row['booking_type'],
            'total_test_count' => 0,
            'slot_id' => 0,
            'date' => '',
            'time' => '',
        ];
    }, $orders);
}
public function hospital_diagnostic_completed_combined_orders($user_id, $limit, $offset,$page){
    $product_orders = $this->get_hospital_diagnostic_completed_bookings($user_id);
    $prescription_orders = $this->get_hospital_diagnostic_completed_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    if(!empty($combined)){
        /*usort($combined, function($a, $b) {
            //return strtotime($b->id ?? $b['id']) - strtotime($a->created_on ?? $a['created_on']);
        });*/
    
        // Pagination manually
        $paged_orders = array_slice($combined, $offset, $limit);
    
        $total_pages   = ceil(count($combined) / $limit);
        $pages = [];
    
        for ($t = 1; $t <= $total_pages; $t++) {
            $pages[] = ['page' => $t];
        }
    
        return [
            'history' => $paged_orders,
            'pagination' => [
                'total_pages'  => $pages,
                'current_page' => $page,
                'limit'        => $limit
            ]
        ];
    }else{
        return [];
    }
}
public function single_hospital_diagnostic_booking_details($booking_id) {
    // Step 1: Get main booking info
    $this->db->select('
        db.id, db.booking_id, db.user_id, db.main_data_id, db.slot_id, db.date, db.time,db.accept_status,db.booking_status,db.booking_type,
        db.booking_status, db.test_status, db.image, db.count, db.fee, db.consultation_fee,  db.coupon_id, db.coupon_name,
         db.coupon_percentage, db.coupon_discount, db.payment_type, db.transaction_id, db.diagnostic_name, db.logo, db.family_member_id,
        d.open_time, d.close_time, d.location
    ');
    $this->db->from('hospital_diagnostic_bookings db');
    $this->db->join('main_data d', 'd.id = db.main_data_id', 'left');
    //$this->db->join('hospital_diagnostic_reports hdr', 'hdr.booking_id = db.booking_id and hdr.booking_type=product_booking', 'left');
    $this->db->where('db.booking_id', $booking_id);
    $booking = $this->db->get()->row_array();

    if (!$booking) return null;

    // Cast integers
    $booking['id'] = intval($booking['id']);
    $booking['user_id'] = intval($booking['user_id']);
    $booking['main_data_id'] = intval($booking['main_data_id']);
    $booking['diagnostic_id'] = intval($booking['main_data_id']);
    $booking['slot_id'] = intval($booking['slot_id']);
    $booking['count'] = intval($booking['count']);
    $booking['fee'] = intval($booking['fee']);
    $booking['consultation_fee'] = intval($booking['consultation_fee']);
    $booking['coupon_id'] = intval($booking['coupon_id']);
    $booking['coupon_percentage'] = intval($booking['coupon_percentage']);
    $booking['coupon_discount'] = intval($booking['coupon_discount']);
    
    $reports = [];
    //if (!empty($booking['family_member_id'])) {
        $this->db->select('image');
        $this->db->from('hospital_diagnostic_reports');
        $this->db->where(['booking_id' => $booking['booking_id'],'booking_type' => $booking['booking_type']]);
        $reports = $this->db->get()->result_array();
    //}
    $booking['reports'] = $reports;
    
    // Step 2: Get family members (if any)
    $family_members = [];
    if (!empty($booking['family_member_id'])) {
        $ids = explode(',', $booking['family_member_id']);
        $clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        if (!empty($clean_ids)) {
            $this->db->select('id, name, dob, gender, email, mobile');
            $this->db->from('family_members');
            $this->db->where_in('id', $clean_ids);
            $family_members = $this->db->get()->result_array();
            foreach ($family_members as &$member) {
                $member['id'] = intval($member['id']);
            }
        }
    }
    $booking['family_members'] = $family_members;

    // Step 3: Join all booking-related data in one query
    $this->db->select("
        p.id AS package_id, p.name AS package_name, p.image, p.one_person, p.one_person_discount,
        p.report_in, p.fasting, p.location AS package_location,

        t.id AS test_id, t.name AS test_name,
        st.id AS sub_test_id, st.name AS sub_test_name
    ");
    $this->db->from('hospital_diagnostic_booking_packages p');
    $this->db->join('hospital_diagnostic_booking_tests t', 't.booking_package_id = p.id AND t.booking_id = p.booking_id', 'left');
    $this->db->join('hospital_diagnostic_booking_subtests st', 'st.booking_test_id = t.id AND st.booking_id = t.booking_id', 'left');
    $this->db->where('p.booking_id', $booking_id);
    $query = $this->db->get();
    $rows = $query->result_array();

    // Step 4: Group data
    $packages = [];
    foreach ($rows as $row) {
        $pkg_id = intval($row['package_id']);
        if (!isset($packages[$pkg_id])) {
            $packages[$pkg_id] = [
                'id' => $pkg_id,
                'name' => $row['package_name'],
                'image' => $row['image'],
                'one_person' => intval($row['one_person']),
                'one_person_discount' => intval($row['one_person_discount']),
                'report_in' => $row['report_in'],
                'fasting' => $row['fasting'],
                'location' => $row['package_location'],
                'tests' => []
            ];
        }

        $test_id = intval($row['test_id']);
        if ($test_id && !isset($packages[$pkg_id]['tests'][$test_id])) {
            $packages[$pkg_id]['tests'][$test_id] = [
                'id' => $test_id,
                'name' => $row['test_name'],
                'sub_tests' => []
            ];
        }

        $sub_test_id = intval($row['sub_test_id']);
        if ($sub_test_id && isset($packages[$pkg_id]['tests'][$test_id])) {
            $packages[$pkg_id]['tests'][$test_id]['sub_tests'][] = [
                'id' => $sub_test_id,
                'name' => $row['sub_test_name']
            ];
        }
    }

    // Final formatting
    foreach ($packages as &$pkg) {
        $pkg['tests'] = array_values($pkg['tests']);
    }

    $booking['packages'] = array_values($packages);
    unset($booking['main_data_id'], $booking['family_member_ids']); // Clean up

    return $booking;
}
public function single_hospital_diagnostic_prescription_orders($booking_id){
    // Step 1: Get main booking info
    $this->db->select('
        db.id, db.booking_id, db.user_id, db.main_data_id, db.image,db.name,db.mobile,db.accept_status,db.booking_status,db.booking_type,
        db.booking_status, db.image, db.diagnostic_name, db.logo, db.family_member_id,
        d.open_time, d.close_time, d.location
    ');
    $this->db->from('hospital_diagnostic_prescription_bookings db');
    $this->db->join('main_data d', 'd.id = db.main_data_id', 'left');
    $this->db->where('db.booking_id', $booking_id);
    $booking = $this->db->get()->row_array();

    if (!$booking) return null;

    // Cast integers
    $booking['id'] = intval($booking['id']);
    $booking['user_id'] = intval($booking['user_id']);
    $booking['main_data_id'] = intval($booking['main_data_id']);
    $booking['diagnostic_id'] = intval($booking['main_data_id']);
    $booking['mobile'] = intval($booking['mobile']);
    
    $reports = [];
    //if (!empty($booking['family_member_id'])) {
        $this->db->select('image');
        $this->db->from('hospital_diagnostic_reports');
        $this->db->where(['booking_id' => $booking['booking_id'],'booking_type' => $booking['booking_type']]);
        $reports = $this->db->get()->result_array();
    //}
    $booking['reports'] = $reports;
    
    // Step 2: Get family members (if any)
    $family_members = [];
    if (!empty($booking['family_member_id'])) {
        $ids = explode(',', $booking['family_member_id']);
        $clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        if (!empty($clean_ids)) {
            $this->db->select('id, name, dob, gender, email');
            $this->db->from('family_members');
            $this->db->where_in('id', $clean_ids);
            $family_members = $this->db->get()->result_array();
            foreach ($family_members as &$member) {
                $member['id'] = intval($member['id']);
            }
        }
    }
    $booking['family_members'] = $family_members;

    unset($booking['main_data_id'], $booking['family_member_id']); // Clean up

    return $booking;
}
public function get_diagnostic_booked_slots($user_id,$date){
    $this->db->select('id as slot_id, time, date, booking_status');
    $this->db->from('hospital_diagnostic_slots');
    $this->db->where('main_data_id', $user_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1); // Ensure only active slots are fetched
    $this->db->where('delete_status', 1); // Ensure only non-deleted slots are fetched

    $results = $this->db->get()->result_array();

    // Normalize time format
    foreach ($results as &$row) {
        $row['time'] = date('h:i A', strtotime($row['time']));
    }

    return $results;
}
public function get_diagnostic_tests($user_id, $limit, $offset){
    // Step 1: Get package IDs
    $this->db->select("id");
    $this->db->from("hospital_diagnostic_packages");
    $this->db->where("main_data_id", $user_id);
    $this->db->where("status", 1);
    $this->db->where("delete_status", 1);
    $this->db->order_by("id", "desc");
    $this->db->limit($limit, $offset);
    $package_query = $this->db->get();
    $package_ids = array_column($package_query->result_array(), 'id');

    if (empty($package_ids)) {
        return []; // No packages found
    }

    // Step 2: Get all related tests and sub-tests
    $this->db->select("
        hospital_diagnostic_packages.id AS package_id,
        hospital_diagnostic_packages.name,
        hospital_diagnostic_packages.image,
        hospital_diagnostic_packages.one_person,
        hospital_diagnostic_packages.one_person_discount,
        hospital_diagnostic_packages.two_person,
        hospital_diagnostic_packages.two_person_discount,
        hospital_diagnostic_packages.three_person,
        hospital_diagnostic_packages.three_person_discount,
        hospital_diagnostic_packages.four_person,
        hospital_diagnostic_packages.four_person_discount,
        hospital_diagnostic_packages.five_person,
        hospital_diagnostic_packages.five_person_discount,
        hospital_diagnostic_packages.report_in,
        hospital_diagnostic_packages.fasting,
        hospital_diagnostic_tests.id AS test_id,
        hospital_diagnostic_tests.name AS test_name,
        hospital_diagnostic_sub_tests.id AS sub_test_id,
        hospital_diagnostic_sub_tests.name AS sub_test_name,
        -- Combined test + subtest count as total_test_count
        (
            (SELECT COUNT(*) FROM hospital_diagnostic_tests hdbt WHERE hdbt.package_id = hospital_diagnostic_packages.id) +
            (SELECT COUNT(*) FROM hospital_diagnostic_sub_tests hdbst WHERE hdbst.package_id = hospital_diagnostic_packages.id)
        ) AS total_test_count
    ");
    $this->db->from('hospital_diagnostic_packages');
    $this->db->join('hospital_diagnostic_tests', 'hospital_diagnostic_tests.package_id = hospital_diagnostic_packages.id AND hospital_diagnostic_tests.main_data_id = hospital_diagnostic_packages.main_data_id AND hospital_diagnostic_tests.status = 1 AND hospital_diagnostic_tests.delete_status = 1', 'left');
    $this->db->join('hospital_diagnostic_sub_tests', 'hospital_diagnostic_sub_tests.test_id = hospital_diagnostic_tests.id AND hospital_diagnostic_sub_tests.package_id = hospital_diagnostic_tests.package_id AND hospital_diagnostic_sub_tests.main_data_id = hospital_diagnostic_tests.main_data_id AND hospital_diagnostic_sub_tests.status = 1 AND hospital_diagnostic_sub_tests.delete_status = 1', 'left');
    $this->db->where_in('hospital_diagnostic_packages.id', $package_ids);
    $this->db->where('hospital_diagnostic_packages.main_data_id', $user_id);
    $this->db->where('hospital_diagnostic_packages.status', 1);
    $this->db->where('hospital_diagnostic_packages.delete_status', 1);
    $this->db->order_by('hospital_diagnostic_packages.id', 'desc');

    $query = $this->db->get();
    $result = $query->result_array();

    // Step 3: Process data
    $final_data = [];

    foreach ($result as $row) {
        $package_id = $row['package_id'];
        $test_id = $row['test_id'];
        $sub_test_id = $row['sub_test_id'];

        if (!isset($final_data[$package_id])) {
            $final_data[$package_id] = [
                'id' => intval($package_id),
                'name' => $row['name'],
                'image' => $row['image'],
                'one_person' => intval($row['one_person']),
                'one_person_discount' => intval($row['one_person_discount']),
                'two_person' => intval($row['two_person']),
                'two_person_discount' => intval($row['two_person_discount']),
                'three_person' => intval($row['three_person']),
                'three_person_discount' => intval($row['three_person_discount']),
                'four_person' => intval($row['four_person']),
                'four_person_discount' => intval($row['four_person_discount']),
                'five_person' => intval($row['five_person']),
                'five_person_discount' => intval($row['five_person_discount']),
                'report_in' => $row['report_in'],
                'fasting' => $row['fasting'],
                'total_test_count' => intval($row['total_test_count']),
                'tests' => []
            ];
        }

        if ($test_id && !isset($final_data[$package_id]['tests'][$test_id])) {
            $final_data[$package_id]['tests'][$test_id] = [
                'id' => intval($test_id),
                'name' => $row['test_name'],
                'sub_tests' => []
            ];
        }

        if ($sub_test_id && isset($final_data[$package_id]['tests'][$test_id])) {
            $final_data[$package_id]['tests'][$test_id]['sub_tests'][] = [
                'id' => intval($sub_test_id),
                'name' => $row['sub_test_name']
            ];
        }
    }

    // Convert associative test arrays to indexed
    foreach ($final_data as &$package) {
        $package['tests'] = array_values($package['tests']);
    }

    return array_values($final_data);
}
public function get_diagnostic_tests_rows($user_id){
    $this->db->from('hospital_diagnostic_packages');
    $this->db->where(['main_data_id' => $user_id,'status' => 1,'delete_status' => 1]);
    return $this->db->count_all_results();
}
/*diagnostic_bookings*/

/*doctor_bookings*/
public function doctor_bookings_history_active($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.consult_type, b.user_id, b.speciality_id, b.doctor_id, b.slot_id, b.time, b.date, b.mobile,b.call_status, b.family_member_id, b.fee, b.consultation_fee, b.coupon_id, b.coupon_percentage, b.coupon_discount, b.patient_name, s.name AS speciality_name, d.name AS doctor_name, fm.email, fm.gender, fm.dob, fm.image,bg.name as blood_group');

    $this->db->from('doctor_bookings b');
    $this->db->join('specialities s', 's.id = b.speciality_id', 'left');
    $this->db->join('doctors d', 'd.id = b.doctor_id', 'left');
    $this->db->join('family_members fm', 'fm.id = b.family_member_id', 'left');
    $this->db->join('blood_groups bg', 'bg.id = fm.blood_group', 'left');
    // Filter active bookings for the doctor
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'booked');

    // Avoid duplicates in case of joins
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                => intval($row['id']),
            'booking_id'        => $row['booking_id'],
            'consult_type'      => $row['consult_type'],
            'user_id'           => intval($row['user_id']),
            'speciality_id'     => intval($row['speciality_id']),
            'doctor_id'         => intval($row['doctor_id']),
            'slot_id'           => intval($row['slot_id']),
            'time'              => $row['time'],
            'date'              => date('d-m-Y', strtotime($row['date'])),
            'mobile'            => intval($row['mobile']),
            'call_status'       => intval($row['call_status']),
            'family_member_id'  => intval($row['family_member_id']),
            'fee'               => intval($row['fee']),
            'consultation_fee'  => intval($row['consultation_fee']),
            'coupon_id'         => intval($row['coupon_id']),
            'coupon_percentage' => intval($row['coupon_percentage']),
            'coupon_discount'   => intval($row['coupon_discount']),
            'speciality_name'   => $row['speciality_name'],
            'name'              => $row['doctor_name'],
            'image'             => $row['image'],
            'patient_name'      => $row['patient_name'],
            'email'             => $row['email'],
            'gender'            => $row['gender'],
            'dob'               => $row['dob'],
            'blood_group'       => $row['blood_group']
        ];
    }, $result);
}
public function doctor_bookings_history_active_rows($user_id){
    $this->db->from('doctor_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'booked');
    return $this->db->count_all_results();
}
/*public function get_doctor_slots($user_id, $selected_date) {
    $today = date('Y-m-d');
    $current_time = date('h:i A'); // Current time in 12-hour format (e.g., 03:20 PM)

    $this->db->select('id, time, session, booking_status, date');
    $this->db->from('doctor_slots');
    $this->db->where('doctor_id', $user_id);
    $this->db->where('date', $selected_date);
    $this->db->where('status', 1);
    $this->db->where('delete_status', 1);

    // If the selected date is today, only show slots after the current time
    if ($selected_date == $today) {
        // Convert current time to 24-hour format for comparison
        $current_time_24hr = date('H:i', strtotime($current_time)); // Convert current time to 24-hour format

        // Use the correct comparison to filter slots after the current time
        $this->db->where('time >=', $current_time);
    }

    $this->db->order_by('time', 'ASC');

    $query = $this->db->get();
    $results = $query->result_array();

    // Group slots by session (morning, afternoon, evening)
    $slots = ['morning' => [], 'afternoon' => [], 'evening' => []];
    foreach ($results as $row) {
        $row['id'] = intval($row['id']); // Convert slot ID to int
        $row['format_date'] = date('d M Y', strtotime($row['date']));
        
        // Convert the time from 12-hour format to 24-hour format for comparison
        $slot_time_24hr = date('H:i', strtotime($row['time'])); // Convert slot time to 24-hour format

        // If today, filter slots before the current time
        if ($selected_date == $today && $slot_time_24hr < $current_time_24hr) {
            continue; // Skip slots that are in the past if today
        }

        // Add the slot to the appropriate session (morning, afternoon, evening)
        if ($slot_time_24hr >= '06:00' && $slot_time_24hr < '12:00') {
            $slots['morning'][] = $row;
        } elseif ($slot_time_24hr >= '12:00' && $slot_time_24hr < '16:00') {
            $slots['afternoon'][] = $row;
        } else {
            $slots['evening'][] = $row;
        }
    }

    return [
        'slots' => $slots
    ];
}*/
public function get_doctor_slots($user_id, $date){
    $today = date('Y-m-d');
    $current_time = date('H:i'); // current time in 24-hour format

    $this->db->select('id, time, session, booking_status, date');
    $this->db->from('doctor_slots');
    $this->db->where('doctor_id', $user_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1);
    $this->db->where('delete_status', 1);

    // If today, filter out past time slots (we do this in PHP after query)
    $this->db->order_by('id', 'ASC'); // Use ID or leave unordered (will sort in PHP)

    $query = $this->db->get();
    $results = $query->result_array();

    $slots = ['morning' => [], 'afternoon' => [], 'evening' => []];

    foreach ($results as $row) {
        $row['id'] = (int)$row['id'];
        $row['format_date'] = date('d M Y', strtotime($row['date']));

        // Convert time (12-hour) to 24-hour for sorting & filtering
        $slot_time_24hr = date('H:i', strtotime($row['time']));

        // Filter out past slots for today's date
        if ($date == $today && $slot_time_24hr < $current_time) {
            continue;
        }

        // Assign session
        if ($slot_time_24hr >= '05:00' && $slot_time_24hr < '12:00') {
            $slots['morning'][] = $row;
        } elseif ($slot_time_24hr >= '12:00' && $slot_time_24hr < '16:00') {
            $slots['afternoon'][] = $row;
        } else {
            $slots['evening'][] = $row;
        }
    }

    // Sort each session manually by slot time
    foreach ($slots as &$session) {
        usort($session, function ($a, $b) {
            return strtotime($a['time']) - strtotime($b['time']);
        });
    }

    return ['slots' => $slots];
}
public function doctor_bookings_history_completed($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.consult_type, b.user_id, b.speciality_id, b.doctor_id, b.slot_id, b.time, b.date, b.mobile, b.call_status, b.family_member_id, b.fee, b.consultation_fee, b.coupon_id, b.coupon_percentage, b.coupon_discount, b.patient_name, s.name AS speciality_name, d.name AS doctor_name, fm.email, fm.gender, fm.dob, fm.image,bg.name as blood_group,GROUP_CONCAT(DISTINCT md.name ORDER BY md.name SEPARATOR ", ") AS qualification');

    $this->db->from('doctor_bookings b');
    $this->db->join('specialities s', 's.id = b.speciality_id', 'left');
    $this->db->join('doctors d', 'd.id = b.doctor_id', 'left');
    $this->db->join('family_members fm', 'fm.id = b.family_member_id', 'left');
    $this->db->join('blood_groups bg', 'bg.id = fm.blood_group', 'left');
    $this->db->join('medical_degrees md', 'FIND_IN_SET(md.id, d.qualification)', 'left');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    $this->db->group_by('b.id');
    $this->db->order_by('b.id', 'DESC');
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    $final_result = [];

    foreach ($result as $row) {
        $booking_id = $row['booking_id'];

        // Fetch medicines
        $medicines = $this->db->get_where('doctor_booking_medicines', ['booking_id' => $booking_id])->result_array();

       $notes = $this->db
            ->select('notes')
            ->get_where('doctor_booking_notes', ['booking_id' => $booking_id])
            ->result_array();
        
        // Extract just the 'notes' values into a simple array
        $note_values = array_column($notes, 'notes');
        
        // Assign directly to your output array
        $data = $note_values;

        // Fetch tests
        $tests = $this->db->get_where('doctor_booking_tests', ['booking_id' => $booking_id])->result_array();

        $final_result[] = [
            'id'                => intval($row['id']),
            'booking_id'        => $row['booking_id'],
            'consult_type'      => $row['consult_type'],
            'user_id'           => intval($row['user_id']),
            'speciality_id'     => intval($row['speciality_id']),
            'doctor_id'         => intval($row['doctor_id']),
            'slot_id'           => intval($row['slot_id']),
            'time'              => $row['time'],
            'date'              => date('d-m-Y', strtotime($row['date'])),
            'mobile'            => intval($row['mobile']),
            'call_status'       => intval($row['call_status']),
            'family_member_id'  => intval($row['family_member_id']),
            'fee'               => intval($row['fee']),
            'consultation_fee'  => intval($row['consultation_fee']),
            'coupon_id'         => intval($row['coupon_id']),
            'coupon_percentage' => intval($row['coupon_percentage']),
            'coupon_discount'   => intval($row['coupon_discount']),
            'speciality_name'   => $row['speciality_name'],
            'name'              => $row['doctor_name'],
            'image'             => $row['image'],
            'patient_name'      => $row['patient_name'],
            'email'             => $row['email'],
            'gender'            => $row['gender'],
            'dob'               => $row['dob'],
            'blood_group'       => $row['blood_group'],
            'qualification'     => $row['qualification'],
            'medicines'         => !empty($medicines) ? $medicines : [],
            'tests'             => !empty($tests) ? $tests : [],
            'notes'             => !empty($notes) ? $data : []
        ];
    }

    return $final_result;
}
public function doctor_bookings_history_completed_rows($user_id){
    $this->db->from('doctor_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    return $this->db->count_all_results();
}
public function doctor_single_booking_history_completed($booking_id){
    $this->db->select('b.id, b.booking_id, b.consult_type, b.user_id, b.speciality_id, b.doctor_id, b.slot_id, b.time, b.date, b.mobile, b.call_status, b.family_member_id, b.fee, b.consultation_fee, b.coupon_id, b.coupon_percentage, b.coupon_discount, b.patient_name, b.booking_status,s.name AS specialization, d.name AS doctor_name, GROUP_CONCAT(DISTINCT md.name ORDER BY md.name SEPARATOR ", ") AS qualification, fm.email, fm.gender, fm.dob, fm.image, bg.name as blood_group');

    $this->db->from('doctor_bookings b');
    $this->db->join('specialities s', 's.id = b.speciality_id', 'left');
    $this->db->join('doctors d', 'd.id = b.doctor_id', 'left');
    $this->db->join('family_members fm', 'fm.id = b.family_member_id', 'left');
    $this->db->join('blood_groups bg', 'bg.id = fm.blood_group', 'left');
    $this->db->join('medical_degrees md', 'FIND_IN_SET(md.id, d.qualification)', 'left');
    $this->db->where('b.booking_id', $booking_id);
    //$this->db->where('b.booking_status', 'completed');
    $this->db->group_by('b.id');
    $this->db->order_by('b.id', 'DESC');
    //$this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    $final_result = [];

    foreach ($result as $row) {
        $booking_id = $row['booking_id'];

        // Fetch medicines
        $medicines = $this->db
        ->select('medicine, medicine_time')
        ->get_where('doctor_booking_medicines', ['booking_id' => $booking_id])
        ->result_array();

        
        // Fetch tests
        $tests = $this->db
        ->select('test, test_instruction')
        ->get_where('doctor_booking_tests', ['booking_id' => $booking_id])
        ->result_array();
        
        // Fetch notes
        
        $notes = $this->db
            ->select('notes')
            ->get_where('doctor_booking_notes', ['booking_id' => $booking_id])
            ->result_array();
        
        // Extract just the 'notes' values into a simple array
        $note_values = array_column($notes, 'notes');
        
        // Assign directly to your output array
        $data = $note_values;

        $final_result[] = [
            'id'                => intval($row['id']),
            'booking_id'        => $row['booking_id'],
            'consult_type'      => $row['consult_type'],
            'user_id'           => intval($row['user_id']),
            'speciality_id'     => intval($row['speciality_id']),
            'doctor_id'         => intval($row['doctor_id']),
            'slot_id'           => intval($row['slot_id']),
            'time'              => $row['time'],
            'date'              => date('d-m-Y', strtotime($row['date'])),
            'mobile'            => intval($row['mobile']),
            'call_status'       => intval($row['call_status']),
            'family_member_id'  => intval($row['family_member_id']),
            'fee'               => intval($row['fee']),
            'consultation_fee'  => intval($row['consultation_fee']),
            'coupon_id'         => intval($row['coupon_id']),
            'coupon_percentage' => intval($row['coupon_percentage']),
            'coupon_discount'   => intval($row['coupon_discount']),
            'specialization'    => $row['specialization'],
            'name'              => $row['doctor_name'],
            'qualification'     => $row['qualification'],
            'image'             => $row['image'],
            'booking_status'    => $row['booking_status'],
            'patient_name'      => $row['patient_name'],
            'email'             => $row['email'],
            'gender'            => $row['gender'],
            'dob'               => $row['dob'],
            'blood_group'       => $row['blood_group'],
            'medicines'         => !empty($medicines) ? $medicines : [],
            'tests'             => !empty($tests) ? $tests : [],
            'notes'             => !empty($notes) ? $data : []
        ];
    }

    return $final_result;
}
/*doctor_bookings*/

/*ambulance_bookings*/
public function ambulance_bookings_history_active($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id, b.date, b.mobile,b.name,b.address_id,b.trip_status,b.accept_status,u.hno,u.colony,u.pincode,u.state,u.landmark,u.address_type,u.default_address,u.lat,u.lon,IFNULL(a.name, "") AS ambulance_driver_name,us.image');

    $this->db->from('ambulance_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'booked');
    
    // accept_status = 'accepted' OR ''
    $this->db->group_start();
    $this->db->where('b.accept_status', 'accepted');
    $this->db->or_where('b.accept_status', '');
    $this->db->group_end();
    
    $this->db->join('user_addresses u','u.id=b.address_id','left');
    $this->db->join('ambulance_drivers a','a.id=b.ambulance_driver_id','left');
    $this->db->join('users us','us.id=b.user_id','left');
    // Avoid duplicates in case of joins
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'ambulance_driver_name' => $row['ambulance_driver_name'],
            'accept_status'         => $row['accept_status'],
            'trip_status'           => $row['trip_status'],
            'address_id'            => intval($row['address_id']),
            'hno'                   => $row['hno'],
            'colony'                => $row['colony'],
            'pincode'               => intval($row['pincode']),
            'state'                 => $row['state'],
            'landmark'              => $row['landmark'],
            'address_type'          => $row['address_type'],
            'default_address'       => intval($row['default_address']),
            'lat'                   => $row['lat'],
            'lon'                   => $row['lon'],
            'image'                 => $row['image']
        ];
    }, $result);
}
public function ambulance_bookings_history_active_rows($user_id){
    $this->db->from('ambulance_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'booked');
    return $this->db->count_all_results();
}
public function ambulance_bookings_history_completed($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id, b.date, b.mobile,b.name,b.address_id,b.trip_status,u.hno,u.colony,u.pincode,u.state,u.landmark,u.address_type,u.default_address,u.lat,u.lon,IFNULL(a.name, "") AS ambulance_driver_name,us.image');

    $this->db->from('ambulance_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    
    $this->db->join('user_addresses u','u.id=b.address_id','left');
    $this->db->join('ambulance_drivers a','a.id=b.ambulance_driver_id','left');
    $this->db->join('users us','us.id=b.user_id','left');
    // Avoid duplicates in case of joins
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'image'                 => $row['image'],
            'ambulance_driver_name' => $row['ambulance_driver_name'],
            'trip_status'           => $row['trip_status'],
            'address_id'            => intval($row['address_id']),
            'hno'                   => $row['hno'],
            'colony'                => $row['colony'],
            'pincode'               => intval($row['pincode']),
            'state'                 => $row['state'],
            'landmark'              => $row['landmark'],
            'address_type'          => $row['address_type'],
            'default_address'       => intval($row['default_address']),
            'lat'                   => $row['lat'],
            'lon'                   => $row['lon']
        ];
    }, $result);
}
public function ambulance_bookings_history_completed_rows($user_id){
    $this->db->from('ambulance_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    return $this->db->count_all_results();
}
public function single_ambulance_booking_details($booking_id){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id, b.date, b.mobile,b.name,b.address_id,b.accept_status,b.trip_status,us.image as user_image,u.hno,u.colony,u.pincode,u.state,u.landmark,u.address_type,u.default_address,u.lat,u.lon,IFNULL(a.name, "") AS ambulance_driver_name,a.mobile as driver_mobile,IFNULL(a.vehicle_number, "") AS vehicle_number,IFNULL(a.image, "") AS image');

    $this->db->from('ambulance_bookings b');
    $this->db->where('b.booking_id', $booking_id);
    
    $this->db->join('user_addresses u','u.id=b.address_id','left');
    $this->db->join('ambulance_drivers a','a.id=b.ambulance_driver_id','left');
    $this->db->join('users us','us.id=b.user_id','left');
    // Avoid duplicates in case of joins
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'ambulance_driver_name' => $row['ambulance_driver_name'],
            'driver_mobile'         => intval($row['driver_mobile']),
            'vehicle_number'        => $row['vehicle_number'],
            'image'                 => $row['image'],
            'accept_status'         => $row['accept_status'],
            'trip_status'           => $row['trip_status'],
            'user_image'            => $row['user_image'],
            'address_id'            => intval($row['address_id']),
            'hno'                   => $row['hno'],
            'colony'                => $row['colony'],
            'pincode'               => intval($row['pincode']),
            'state'                 => $row['state'],
            'landmark'              => $row['landmark'],
            'address_type'          => $row['address_type'],
            'default_address'       => intval($row['default_address']),
            'lat'                   => $row['lat'],
            'lon'                   => $row['lon']
        ];
    }, $result);
}
/*ambulance_bookings*/

/*admit_bookings*/
public function admit_bookings_history_active($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id,b.pr_id, b.date,b.time, b.mobile,b.name,fm.image,IFNULL(pr.name, "") AS pr_name,IFNULL(pr.image, "") AS pr_image,pr.mobile as pr_mobile');

    $this->db->from('admit_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'booked');
    
    $this->db->join('family_members fm','fm.id=b.family_member_id','left');
    
    $this->db->join('pr_agents pr','pr.id=b.pr_id','left');
    
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'pr_id'                 => intval($row['pr_id']),
            //'slot_id'               => intval($row['slot_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'time'                  => $row['time'],
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'image'                 => $row['image'],
            'pr_name'               => $row['pr_name'],
            'pr_image'              => $row['pr_image'],
            'pr_mobile'             => intval($row['pr_mobile'])
        ];
    }, $result);
}
public function admit_bookings_history_active_rows($user_id){
    $this->db->from('admit_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'booked');
    return $this->db->count_all_results();
}
public function get_hospital_slots($main_data_id, $date){
    $today = date('Y-m-d');
    $current_time = date('H:i'); // current time in 24-hour format

    $this->db->select('id, time, session, booking_status, date');
    $this->db->from('hospital_slots');
    $this->db->where('main_data_id', $main_data_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1);
    $this->db->where('delete_status', 1);

    // If today, filter out past time slots (we do this in PHP after query)
    $this->db->order_by('id', 'ASC'); // Use ID or leave unordered (will sort in PHP)

    $query = $this->db->get();
    $results = $query->result_array();

    $slots = ['morning' => [], 'afternoon' => [], 'evening' => []];

    foreach ($results as $row) {
        $row['id'] = (int)$row['id'];
        $row['format_date'] = date('d M Y', strtotime($row['date']));

        // Convert time (12-hour) to 24-hour for sorting & filtering
        $slot_time_24hr = date('H:i', strtotime($row['time']));

        // Filter out past slots for today's date
        if ($date == $today && $slot_time_24hr < $current_time) {
            continue;
        }

        // Assign session
        if ($slot_time_24hr >= '05:00' && $slot_time_24hr < '12:00') {
            $slots['morning'][] = $row;
        } elseif ($slot_time_24hr >= '12:00' && $slot_time_24hr < '16:00') {
            $slots['afternoon'][] = $row;
        } else {
            $slots['evening'][] = $row;
        }
    }

    // Sort each session manually by slot time
    foreach ($slots as &$session) {
        usort($session, function ($a, $b) {
            return strtotime($a['time']) - strtotime($b['time']);
        });
    }

    return ['slots' => $slots];
}
public function admit_bookings_completed($user_id, $limit, $offset){
    $this->db->select('b.id, b.booking_id, b.user_id, b.main_data_id,b.pr_id, b.date, b.time, b.mobile,b.name,fm.image,IFNULL(pr.name, "") AS pr_name,IFNULL(pr.image, "") AS pr_image,pr.mobile as pr_mobile');

    $this->db->from('admit_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    
    $this->db->join('family_members fm','fm.id=b.family_member_id','left');
    
    $this->db->join('pr_agents pr','pr.id=b.pr_id','left');
    
    $this->db->group_by('b.id');

    // Custom ordering: today's bookings first, then older dates
    $today = date('Y-m-d');
    $this->db->order_by("CASE 
        WHEN b.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('b.date', 'DESC'); // Then remaining in descending order

    // Pagination
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    // Format and return result
    return array_map(function ($row) {
        return [
            'id'                    => intval($row['id']),
            'booking_id'            => $row['booking_id'],
            'user_id'               => intval($row['user_id']),
            'main_data_id'          => intval($row['main_data_id']),
            'pr_id'                 => intval($row['pr_id']),
            //'slot_id'               => intval($row['slot_id']),
            'date'                  => date('d-m-Y', strtotime($row['date'])),
            'time'                  => $row['time'],
            'mobile'                => intval($row['mobile']),
            'name'                  => $row['name'],
            'image'                 => $row['image'],
            'pr_name'               => $row['pr_name'],
            'pr_image'              => $row['pr_image'],
            'pr_mobile'             => intval($row['pr_mobile'])
        ];
    }, $result);
}
public function admit_bookings_completed_rows($user_id){
    $this->db->from('admit_bookings b');
    $this->db->where('b.main_data_id', $user_id);
    $this->db->where('b.booking_status', 'completed');
    return $this->db->count_all_results();
}
public function single_admit_booking_details($booking_id){
    // Step 1: Get booking data
    $today = date('Y-m-d');

    $this->db->select('
        b.id, b.booking_id, b.user_id, b.main_data_id, b.pr_id, 
        b.date,  b.time, b.mobile, b.name, b.family_member_id,
        fm.image AS family_image,b.booking_status,
        IFNULL(pr.name, "") AS pr_name,
        IFNULL(pr.image, "") AS pr_image,
        IFNULL(pr.mobile, 0) AS pr_mobile
    ');
    $this->db->from('admit_bookings b');
    $this->db->join('family_members fm', 'fm.id = b.family_member_id', 'left');
    $this->db->join('pr_agents pr', 'pr.id = b.pr_id', 'left');
    $this->db->where('b.booking_id', $booking_id);
    $this->db->group_by('b.id');
    $this->db->order_by("CASE WHEN b.date = '{$today}' THEN 0 ELSE 1 END", "ASC");
    $this->db->order_by('b.date', 'DESC');

    $query = $this->db->get();
    $results = $query->result_array();

    if (empty($results)) return null;

    // Step 2: Get booking_id from first row for reports
    $booking_id = $results[0]['booking_id'];

    $this->db->select('image');
    $this->db->from('admit_booking_reports');
    $this->db->where('booking_id', $booking_id);
    $reports = $this->db->get()->result_array();

    // Step 3: Get family members
    $family_members = [];
    $family_member_ids = [];

    foreach ($results as $row) {
        if (!empty($row['family_member_id'])) {
            $ids = explode(',', $row['family_member_id']);
            foreach ($ids as $id) {
                $clean_id = intval(trim($id));
                if ($clean_id > 0) {
                    $family_member_ids[] = $clean_id;
                }
            }
        }
    }

    $family_member_ids = array_unique($family_member_ids);
    if (!empty($family_member_ids)) {
        $this->db->select('id, name, dob, gender, email, mobile');
        $this->db->from('family_members');
        $this->db->where_in('id', $family_member_ids);
        $family_members = $this->db->get()->result_array();
    }

    // Step 4: Prepare response
    $final = [];

    foreach ($results as $row) {
        $final[] = [
            'id'              => (int) $row['id'],
            'booking_id'      => $row['booking_id'],
            'user_id'         => (int) $row['user_id'],
            'main_data_id'    => (int) $row['main_data_id'],
            'pr_id'           => (int) $row['pr_id'],
            //'slot_id'         => (int) $row['slot_id'],
            'date'            => date('d-m-Y', strtotime($row['date'])),
            'time'            => $row['time'],
            'mobile'          => $row['mobile'],
            'name'            => $row['name'],
            'image'           => $row['family_image'],
            'booking_status'  => $row['booking_status'],
            'pr_name'         => $row['pr_name'],
            'pr_image'        => $row['pr_image'],
            'pr_mobile'       => $row['pr_mobile'],
            'reports'         => $reports,
            //'family_members'  => $family_members
        ];
    }

    return $final;
}
public function get_hospital_booked_slots($user_id,$date){
    $this->db->select('id as slot_id, time, date, booking_status');
    $this->db->from('hospital_slots');
    $this->db->where('main_data_id', $user_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1); // Ensure only active slots are fetched
    $this->db->where('delete_status', 1); // Ensure only non-deleted slots are fetched

    $results = $this->db->get()->result_array();

    // Normalize time format
    foreach ($results as &$row) {
        $row['time'] = date('h:i A', strtotime($row['time']));
    }

    return $results;
}
/*admit_bookings*/

/*home_page*/

/*hamburger*/
public function get_main_data($user_id){
    $this->db->select("
        main_data.*, categories.name as tagline,
        GROUP_CONCAT(DISTINCT img.image) AS images,
        GROUP_CONCAT(DISTINCT CONCAT(specialities.id, '|', specialities.name, '|', specialities.image)) AS specialities
    ", false); 
    
    $this->db->from('main_data');

    // Join images table
    $this->db->join('images img', 'img.cat_id = main_data.cat_id AND img.main_data_id = main_data.id AND img.status=1 AND img.delete_status=1', 'left');

    // Join specialities
    $this->db->join('main_data_specialities', 'main_data_specialities.main_data_id = main_data.id AND main_data_specialities.status=1 AND main_data_specialities.delete_status=1', 'left');
    $this->db->join('specialities', 'specialities.id = main_data_specialities.speciality_id', 'left');
    $this->db->join('categories', 'categories.id = main_data.cat_id', 'left');
    // Filters
    //$this->db->where('main_data.cat_id', $cat_id);
    $this->db->where('main_data.id', $user_id);
    //$this->db->where('main_data.status', 1);
    //$this->db->where('main_data.delete_status', 1);

    // Grouping & Sorting
    $this->db->group_by('main_data.id');
    

    $query = $this->db->get();
    $result = $query->result_array();

    return array_map(function ($row) {
        // Fetch pharmacy categories if pharmacy is yes
        // Fetch pharmacy categories if pharmacy is yes
        $pharmacy_categories = [];
        if (strtolower($row['pharmacy']) === 'yes') {
            $CI =& get_instance();
            $CI->db->select('id, name, image');
            $CI->db->from('pharmacy_categories');
            $CI->db->where('status', 1);
            $CI->db->where('delete_status', 1);
            $pharmacy_categories = array_map(function ($item) {
                return [
                    'id'    => intval($item['id']),
                    'name'  => $item['name'],
                    'image' => $item['image']
                ];
            }, $CI->db->get()->result_array());
        }


        // Diagnostic array is empty for now if diagnostic = 'yes'
        $diagnostic_categories = (strtolower($row['diagnostic']) === 'yes') ? [] : null;

        return [
            'id'          => intval($row['id']),
            'name'        => $row['name'],
            'mobile'      => intval($row['mobile']),
            'email'       => $row['email'],
            'tagline'     => $row['tagline'],
            'logo'        => $row['logo'],
            'open_time'   => $row['open_time'],
            'close_time'  => $row['close_time'],
            'location'    => $row['location'],
            'description' => $row['description'],
            'cat_id'      => intval($row['cat_id']),
            'sub_cat_id'      => intval($row['sub_cat_id']),
            'sub_sub_cat_id'  => intval($row['sub_sub_cat_id']),
            'lat'         => $row['lat'],
            'lon'         => $row['lon'],
            'pharmacy'    => $row['pharmacy'],
            'diagnostic'  => $row['diagnostic'],
            'home_delivery' => $row['home_delivery'],
            'images'      => (!empty($row['images']) && is_string($row['images']))
                ? array_map(function ($image) {
                    return ['url' => trim($image)];
                }, array_filter(explode(',', $row['images'])))
                : [],
            'specialities' => (!empty($row['specialities']) && is_string($row['specialities']))
                ? array_map(function ($speciality) {
                    list($id, $name, $image) = explode('|', $speciality);
                    return [
                        'id'    => intval($id),
                        'name'  => $name,
                        'image' => $image
                    ];
                }, array_filter(explode(',', $row['specialities'])))
                : [],
            //'pharmacy_categories'   => $pharmacy_categories,
            //'diagnostic_categories' => $diagnostic_categories,
        ];
    }, $result);
}
/*hamburger*/


}

?>