<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Ws_model extends CI_Model{

/*default functions*/
public function common_fetch($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','desc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_fetch_select($table, $where = [], $select = '*', $integerFields = []) {
    $this->db->select($select);
    $this->db->from($table);
    
    if (!empty($where)) {
        $this->db->where($where);
    }
    $this->db->order_by('id','desc');
    $query = $this->db->get();
    
    if ($query->num_rows() > 0) {
        $result = $query->result_array();
        
        // Type-cast requested fields to integer
        if (!empty($integerFields)) {
            foreach ($result as &$row) {
                foreach ($integerFields as $field) {
                    if (isset($row[$field])) {
                        $row[$field] = (int) $row[$field];
                    }
                }
            }
            unset($row);
        }
        
        return $result;
    } else {
        return [];
    }
}
public function common_fetch_asc($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','asc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_insert($table,$data){	
	$this->db->insert($table,$data);
	$id = $this->db->insert_id();
	return $id;
}
public function common_update($table,$data,$where){
	$this->db->where($where);
	$this->db->update($table,$data);
}
public function common_delete($table,$where){
	$this->db->where($where);
	$this->db->delete($table);
}
public function common_fetch_rows($table,$where){
	$this->db->where($where);	
	$query = $this->db->get($table);
	return $query->num_rows();
}
// In your Ws_model.php
public function is_exists($table, $where = []) {
    $this->db->from($table);
    if (!empty($where)) {
        $this->db->where($where);
    }
    $query = $this->db->limit(1)->get();
    return $query->num_rows() > 0;
}
/*default functions*/

/*home_page*/
public function get_lab_test_bookings($user_id) {
    $this->db->select('
        db.id,
        db.booking_id,
        db.created_on,
        db.user_id,
        db.main_data_id,
        db.booking_status,
        db.booking_type,
        hdbp.name,
        db.count,
        db.image,
        db.mobile,
        db,test_status,
        -- Combined test + subtest count as total_test_count
        (
            (SELECT COUNT(*) FROM lab_test_booking_tests hdbt WHERE hdbt.booking_id = db.booking_id) +
            (SELECT COUNT(*) FROM lab_test_booking_subtests hdbst WHERE hdbst.booking_id = db.booking_id)
        ) AS total_test_count
    ');
    $this->db->from('lab_test_bookings db');
    $this->db->where('db.main_data_id', $user_id);
    $this->db->where('booking_status', 'booked');
    
    // accept_status = 'accepted' OR ''
    $this->db->group_start();
    $this->db->where('db.accept_status', 'accepted');
    $this->db->or_where('db.accept_status', '');
    $this->db->group_end();

    $this->db->join('lab_tests d','d.id=db.main_data_id','left');
    $this->db->join('lab_test_booking_packages hdbp','hdbp.booking_id=db.booking_id','left');
    $this->db->order_by("CASE 
        WHEN db.date = '{$today}' THEN 0 
        ELSE 1 
    END", "ASC"); // Today comes first
    $this->db->order_by('db.date', 'DESC'); // Then remaining in descending order

    $query = $this->db->get();
    $result = $query->result_array();

    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id' => $row['booking_id'],
            'created_on' => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => intval($row['count']),
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type' => $row['booking_type'],
            'total_test_count' => intval($row['total_test_count']),
            'test_status' => $row['test_status'],
        ];
    }, $result);
}
public function get_lab_test_prescription_orders($user_id){
    $this->db->select('dpb.id, dpb.booking_id, dpb.created_on,dpb.user_id,dpb.main_data_id,dpb.image,dpb.accept_status,dpb.booking_status,dpb.booking_type,dpb.image,dpb.name,dpb.mobile,dpb.test_status');
    $this->db->from('lab_test_prescription_bookings dpb');
    $this->db->where(['dpb.main_data_id' => $user_id,'dpb.booking_status' => 'booked']);
    
    // Add accept_status = 'accepted' OR accept_status = ''
    $this->db->group_start();
    $this->db->where('dpb.accept_status', 'accepted');
    $this->db->or_where('dpb.accept_status', '');
    $this->db->group_end();
    //$this->db->join('main_data d','d.id=dpb.main_data_id','left');
    $this->db->order_by('dpb.id', 'DESC');

    $query = $this->db->get();
    $orders = $query->result_array();
    
    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id'    => $row['booking_id'],
            'created_on'    => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => 0,
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type'      => $row['booking_type'],
            'total_test_count' => 0,
            'test_status' => $row['test_status'],
        ];
    }, $orders);
}
public function lab_test_combined_orders($user_id, $limit, $offset,$page){
    $product_orders = $this->get_lab_test_bookings($user_id);
    $prescription_orders = $this->get_lab_test_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    if(!empty($combined)){
        /*usort($combined, function($a, $b) {
            //return strtotime($b->id ?? $b['id']) - strtotime($a->created_on ?? $a['created_on']);
        });*/
    
        // Pagination manually
        $paged_orders = array_slice($combined, $offset, $limit);
    
        $total_pages   = ceil(count($combined) / $limit);
        $pages = [];
    
        for ($t = 1; $t <= $total_pages; $t++) {
            $pages[] = ['page' => $t];
        }
    
        return [
            'history' => $paged_orders,
            'pagination' => [
                'total_pages'  => $pages,
                'current_page' => $page,
                'limit'        => $limit
            ]
        ];
    }else{
        return [];
    }
}
public function agents($user_id,$limit,$offset){
    $this->db->where(['main_data_id' => $user_id,'availability' => 1,'status' => 1,'delete_status' => 1]);
    $this->db->order_by('id','desc');
    $this->db->limit($limit,$offset);
    $query = $this->db->get('lab_agents');
    $result =  $query->result_array();
    
    return array_map(function ($row) {
        return [
            'id'                => intval($row['id']),
            'main_data_id'      => intval($row['main_data_id']),
            'name'              => $row['name'],
            'mobile'            => intval($row['mobile']),
            'image'             => $row['image']
        ];
    }, $result);
}
public function agents_rows($user_id){
    $this->db->where(['main_data_id' => $user_id,'availability' => 1,'status' => 1,'delete_status' => 1]);
    $query = $this->db->get('lab_agents');
    return $query->num_rows();
}
public function get_lab_test_slots($main_data_id, $date) {
    $today = date('Y-m-d');
    $current_time = date('H:i'); // current time in 24-hour format

    $this->db->select('id, time, session, booking_status, date');
    $this->db->from('lab_test_slots');
    $this->db->where('main_data_id', $main_data_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1);
    $this->db->where('delete_status', 1);

    // If today, filter out past time slots (we do this in PHP after query)
    $this->db->order_by('id', 'ASC'); // Use ID or leave unordered (will sort in PHP)

    $query = $this->db->get();
    $results = $query->result_array();

    $slots = ['morning' => [], 'afternoon' => [], 'evening' => []];

    foreach ($results as $row) {
        $row['id'] = (int)$row['id'];
        $row['format_date'] = date('d M Y', strtotime($row['date']));

        // Convert time (12-hour) to 24-hour for sorting & filtering
        $slot_time_24hr = date('H:i', strtotime($row['time']));

        // Filter out past slots for today's date
        if ($date == $today && $slot_time_24hr < $current_time) {
            continue;
        }

        // Assign session
        if ($slot_time_24hr >= '05:00' && $slot_time_24hr < '12:00') {
            $slots['morning'][] = $row;
        } elseif ($slot_time_24hr >= '12:00' && $slot_time_24hr < '16:00') {
            $slots['afternoon'][] = $row;
        } else {
            $slots['evening'][] = $row;
        }
    }

    // Sort each session manually by slot time
    foreach ($slots as &$session) {
        usort($session, function ($a, $b) {
            return strtotime($a['time']) - strtotime($b['time']);
        });
    }

    return ['slots' => $slots];
}
public function get_lab_test_completed_bookings($user_id) {
    $this->db->select('
        db.id,
        db.booking_id,
        db.created_on,
        db.user_id,
        db.main_data_id,
        db.booking_status,
        db.booking_type,
        hdbp.name,
        db.count,
        db.image,
        db.mobile,
        db.test_status,
        -- Combined test + subtest count as total_test_count
        (
            (SELECT COUNT(*) FROM lab_test_booking_tests hdbt WHERE hdbt.booking_id = db.booking_id) +
            (SELECT COUNT(*) FROM lab_test_booking_subtests hdbst WHERE hdbst.booking_id = db.booking_id)
        ) AS total_test_count
    ');
    $this->db->from('lab_test_bookings db');
    $this->db->where('db.main_data_id', $user_id);
    $this->db->where('db.booking_status', 'completed');


    $this->db->join('lab_tests d','d.id=db.main_data_id','left');
    $this->db->join('lab_test_booking_packages hdbp','hdbp.booking_id=db.booking_id','left');
    $this->db->order_by('db.id', 'DESC');

    $query = $this->db->get();
    $result = $query->result_array();

    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id' => $row['booking_id'],
            'created_on' => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => intval($row['count']),
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type' => $row['booking_type'],
            'total_test_count' => intval($row['total_test_count']),
            'test_status' => $row['test_status']
        ];
    }, $result);
}
public function get_lab_test_completed_prescription_orders($user_id){
    $this->db->select('dpb.id, dpb.booking_id, dpb.created_on,dpb.user_id,dpb.main_data_id,dpb.image,dpb.accept_status,dpb.booking_status,dpb.booking_type,dpb.name,dpb.mobiledpb.test_status');
    $this->db->from('lab_test_prescription_bookings dpb');
    $this->db->where(['main_data_id' => $user_id,'booking_status' => 'completed']);
    // Add accept_status = 'accepted' OR accept_status = ''
    
    //$this->db->join('main_data d','d.id=dpb.main_data_id','left');
    $this->db->order_by('dpb.id', 'DESC');

    $query = $this->db->get();
    $orders = $query->result_array();
    
    return array_map(function ($row) {
        return [
            'id' => intval($row['id']),
            'booking_id'    => $row['booking_id'],
            'created_on'    => $row['created_on'],
            'user_id' => intval($row['user_id']),
            'diagnostic_id' => intval($row['main_data_id']),
            'name' => $row['name'],
            'mobile' => intval($row['mobile']),
            'count' => 0,
            'image' => $row['image'],
            'booking_status' => $row['booking_status'],
            'booking_type'      => $row['booking_type'],
            'total_test_count' => 0,
            'test_status' => $row['test_status']
        ];
    }, $orders);
}
public function lab_test_completed_combined_orders($user_id, $limit, $offset,$page){
    $product_orders = $this->get_lab_test_completed_bookings($user_id);
    $prescription_orders = $this->get_lab_test_completed_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    if(!empty($combined)){
        /*usort($combined, function($a, $b) {
            //return strtotime($b->id ?? $b['id']) - strtotime($a->created_on ?? $a['created_on']);
        });*/
    
        // Pagination manually
        $paged_orders = array_slice($combined, $offset, $limit);
    
        $total_pages   = ceil(count($combined) / $limit);
        $pages = [];
    
        for ($t = 1; $t <= $total_pages; $t++) {
            $pages[] = ['page' => $t];
        }
    
        return [
            'history' => $paged_orders,
            'pagination' => [
                'total_pages'  => $pages,
                'current_page' => $page,
                'limit'        => $limit
            ]
        ];
    }else{
        return [];
    }
}
public function single_lab_test_booking_details($booking_id){
    // Step 1: Get main booking info
    $this->db->select('
        db.id, db.booking_id, db.user_id, db.main_data_id, db.address_id, db.slot_id, db.date, db.time,db.accept_status,db.booking_status,db.booking_type,
        db.booking_status, db.test_status, db.image, db.count, db.fee, db.consultation_fee,  db.coupon_id, db.coupon_name,
         db.coupon_percentage, db.coupon_discount, db.payment_type, db.transaction_id, hdbp.name,db.family_member_id,db.agent_id,db.mobile,db.test_status,
    (
            (SELECT COUNT(*) FROM diagnostic_booking_tests hdbt WHERE hdbt.booking_id = db.booking_id) +
            (SELECT COUNT(*) FROM diagnostic_booking_subtests hdbst WHERE hdbst.booking_id = db.booking_id)
        ) AS total_test_count');
    $this->db->from('lab_test_bookings db');
    $this->db->join('lab_test_booking_packages hdbp', 'hdbp.booking_id = db.booking_id', 'left');
    //$this->db->join('lab_test_reports hdr', 'hdr.booking_id = db.booking_id and hdr.booking_type=db.booking_type', 'left');
    $this->db->where('db.booking_id', $booking_id);
    $booking = $this->db->get()->row_array();

    if (!$booking) return null;

    // Cast integers
    $booking['id'] = intval($booking['id']);
    $booking['user_id'] = intval($booking['user_id']);
    $booking['main_data_id'] = intval($booking['main_data_id']);
    $booking['address_id'] = intval($booking['address_id']);
    $booking['lab_test_id'] = intval($booking['main_data_id']);
    $booking['slot_id'] = intval($booking['slot_id']);
    $booking['count'] = intval($booking['count']);
    $booking['fee'] = intval($booking['fee']);
    $booking['consultation_fee'] = intval($booking['consultation_fee']);
    $booking['coupon_id'] = intval($booking['coupon_id']);
    $booking['coupon_percentage'] = intval($booking['coupon_percentage']);
    $booking['coupon_discount'] = intval($booking['coupon_discount']);
    $booking['total_test_count'] = intval($booking['total_test_count']);
    $booking['agent_id'] = intval($booking['agent_id']);
    $booking['mobile'] = intval($booking['mobile']);
    
    // Step 2: Get family members (if any)
    $reports = [];
    //if (!empty($booking['family_member_id'])) {
        $this->db->select('image');
        $this->db->from('lab_test_reports');
        $this->db->where(['booking_id' => $booking['booking_id'],'booking_type' => $booking['booking_type']]);
        $reports = $this->db->get()->result_array();
    //}
    $booking['reports'] = $reports;
    
    // Step 2: Get family members (if any)
    $family_members = [];
    if (!empty($booking['family_member_id'])) {
        $ids = explode(',', $booking['family_member_id']);
        $clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        if (!empty($clean_ids)) {
            $this->db->select('id, name, dob, gender, email');
            $this->db->from('family_members');
            $this->db->where_in('id', $clean_ids);
            $family_members = $this->db->get()->result_array();
            foreach ($family_members as &$member) {
                $member['id'] = intval($member['id']);
            }
        }
    }
    $booking['family_members'] = $family_members;
    
    // Step 3: Get address (if any)
    //$family_members = [];
    if (!empty($booking['address_id'])) {
        //$ids = explode(',', $booking['family_member_id']);
        //$clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        //if (!empty($clean_ids)) {
            $this->db->select('id,hno, colony, pincode, state, landmark,address_type,default_address,lat,lon');
            $this->db->from('user_addresses');
            $this->db->where('id', $booking['address_id']);
            $address = $this->db->get()->result_array();
            $address[0]['id'] = intval($address[0]['id']);
            $address[0]['default_address'] = intval($address[0]['default_address']);
        //}
    }
    $booking['address'] = $address[0];
    
    // Step 4: Get agent (if any)
    //$family_members = [];
    if ($booking['agent_id']!=0) {
        //$ids = explode(',', $booking['family_member_id']);
        //$clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        //if (!empty($clean_ids)) {
            $this->db->select('id,name, image, mobile');
            $this->db->from('lab_agents');
            $this->db->where('id', $booking['agent_id']);
            $agent = $this->db->get()->result_array();
            $agent[0]['id'] = intval($agent[0]['id']);
            $agent[0]['mobile'] = intval($agent[0]['mobile']);
        //}
        $booking['agent'] = $agent[0];
    }else{
        $booking['agent'] = (object)[];
    }
    

    // Step 3: Join all booking-related data in one query
    $this->db->select("
        p.id AS package_id, p.name AS package_name, p.image, p.one_person, p.one_person_discount,
        p.report_in, p.fasting, p.location AS package_location,

        t.id AS test_id, t.name AS test_name,
        st.id AS sub_test_id, st.name AS sub_test_name
    ");
    $this->db->from('lab_test_booking_packages p');
    $this->db->join('lab_test_booking_tests t', 't.booking_package_id = p.id AND t.booking_id = p.booking_id', 'left');
    $this->db->join('lab_test_booking_subtests st', 'st.booking_test_id = t.id AND st.booking_id = t.booking_id', 'left');
    $this->db->where('p.booking_id', $booking_id);
    $query = $this->db->get();
    $rows = $query->result_array();

    // Step 4: Group data
    $packages = [];
    foreach ($rows as $row) {
        $pkg_id = intval($row['package_id']);
        if (!isset($packages[$pkg_id])) {
            $packages[$pkg_id] = [
                'id' => $pkg_id,
                'name' => $row['package_name'],
                'image' => $row['image'],
                'one_person' => intval($row['one_person']),
                'one_person_discount' => intval($row['one_person_discount']),
                'report_in' => $row['report_in'],
                'fasting' => $row['fasting'],
                'location' => $row['package_location'],
                'tests' => []
            ];
        }

        $test_id = intval($row['test_id']);
        if ($test_id && !isset($packages[$pkg_id]['tests'][$test_id])) {
            $packages[$pkg_id]['tests'][$test_id] = [
                'id' => $test_id,
                'name' => $row['test_name'],
                'sub_tests' => []
            ];
        }

        $sub_test_id = intval($row['sub_test_id']);
        if ($sub_test_id && isset($packages[$pkg_id]['tests'][$test_id])) {
            $packages[$pkg_id]['tests'][$test_id]['sub_tests'][] = [
                'id' => $sub_test_id,
                'name' => $row['sub_test_name']
            ];
        }
    }

    // Final formatting
    foreach ($packages as &$pkg) {
        $pkg['tests'] = array_values($pkg['tests']);
    }

    $booking['packages'] = array_values($packages);
    unset($booking['main_data_id'], $booking['family_member_ids']); // Clean up

    return $booking;
}
public function single_lab_test_prescription_orders($booking_id){
    // Step 1: Get main booking info
    $this->db->select('
        db.id, db.booking_id, db.user_id, db.main_data_id, db.image,db.name,db.mobile,db.accept_status,db.booking_status,db.booking_type,
        db.booking_status, db.image, db.lab_test_name, db.logo, db.family_member_id,db.address_id,
        d.open_time, d.close_time, d.location,db.test_status
    ');
    $this->db->from('lab_test_prescription_bookings db');
    $this->db->join('lab_tests d', 'd.id = db.main_data_id', 'left');
    $this->db->join('lab_test_reports hdr', 'hdr.booking_id = db.booking_id and hdr.booking_type=db.booking_type', 'left');
    $this->db->where('db.booking_id', $booking_id);
    $booking = $this->db->get()->row_array();

    if (!$booking) return null;

    // Cast integers
    $booking['id'] = intval($booking['id']);
    $booking['user_id'] = intval($booking['user_id']);
    $booking['main_data_id'] = intval($booking['main_data_id']);
    $booking['lab_test_id'] = intval($booking['main_data_id']);
    $booking['mobile'] = intval($booking['mobile']);
    $booking['address_id'] = intval($booking['address_id']);
    
    $reports = [];
    //if (!empty($booking['family_member_id'])) {
        $this->db->select('image');
        $this->db->from('lab_test_reports');
        $this->db->where(['booking_id' => $booking['booking_id'],'booking_type' => $booking['booking_type']]);
        $reports = $this->db->get()->result_array();
    //}
    $booking['reports'] = $reports;
    
    // Step 2: Get family members (if any)
    $family_members = [];
    if (!empty($booking['family_member_id'])) {
        $ids = explode(',', $booking['family_member_id']);
        $clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        if (!empty($clean_ids)) {
            $this->db->select('id, name, dob, gender, email');
            $this->db->from('family_members');
            $this->db->where_in('id', $clean_ids);
            $family_members = $this->db->get()->result_array();
            foreach ($family_members as &$member) {
                $member['id'] = intval($member['id']);
            }
        }
    }
    $booking['family_members'] = $family_members;

    unset($booking['main_data_id'], $booking['family_member_id']); // Clean up
    
    // Step 3: Get address (if any)
    //$family_members = [];
    if (!empty($booking['address_id'])) {
        //$ids = explode(',', $booking['family_member_id']);
        //$clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        //if (!empty($clean_ids)) {
            $this->db->select('id,hno, colony, pincode, state, landmark,address_type,default_address,lat,lon');
            $this->db->from('user_addresses');
            $this->db->where('id', $booking['address_id']);
            $address = $this->db->get()->result_array();
            $address[0]['id'] = intval($address[0]['id']);
            $address[0]['default_address'] = intval($address[0]['default_address']);
        //}
    }
    $booking['address'] = $address[0];
    
    // Step 4: Get agent (if any)
    //$family_members = [];
    if ($booking['agent_id']!=0) {
        //$ids = explode(',', $booking['family_member_id']);
        //$clean_ids = array_map('intval', array_filter($ids)); // Clean empty/null
        //if (!empty($clean_ids)) {
            $this->db->select('id,name, image, mobile');
            $this->db->from('lab_agents');
            $this->db->where('id', $booking['agent_id']);
            $agent = $this->db->get()->result_array();
            $agent[0]['id'] = intval($agent[0]['id']);
            $agent[0]['mobile'] = intval($agent[0]['mobile']);
        //}
        $booking['agent'] = $agent[0];
    }else{
        $booking['agent'] = (object)[];
    }
    
    return $booking;
}
/*home_page*/

/*hambuerger*/
public function get_lab_test_booked_slots($user_id,$date){
    $this->db->select('id as slot_id, time, date, booking_status');
    $this->db->from('lab_test_slots');
    $this->db->where('main_data_id', $user_id);
    $this->db->where('date', $date);
    $this->db->where('status', 1); // Ensure only active slots are fetched
    $this->db->where('delete_status', 1); // Ensure only non-deleted slots are fetched

    $results = $this->db->get()->result_array();

    // Normalize time format
    foreach ($results as &$row) {
        $row['time'] = date('h:i A', strtotime($row['time']));
    }

    return $results;
}
public function get_main_data($user_id){
    $this->db->select("
        lab_tests.id,lab_tests.name,lab_tests.mobile,lab_tests.email,lab_tests.open_time,lab_tests.close_time,lab_tests.logo,lab_tests.location,lab_tests.lat,lab_tests.lon,lab_tests.description", false);
    $this->db->from('lab_tests');
    
    // Filters
    $this->db->where('lab_tests.id', $user_id);

    
    // Grouping
    $query = $this->db->get();
    $result = $query->result_array();
    return array_map(function ($row) {
        return [
            'id'            => intval($row['id']),
            'name'          => $row['name'],
            'mobile'        => intval($row['mobile']),
            'email'         => $row['email'],
            'logo'          => $row['logo'],
            'open_time'     => $row['open_time'],
            'close_time'    => $row['close_time'],
            'location'      => $row['location'],
            'lat'           => $row['lat'],
            'lon'           => $row['lon'],
            'description'   => $row['description']
        ];
    }, $result);
}
public function get_lab_tests($user_id, $limit, $offset){
    // Step 1: Get package IDs
    $this->db->select("id");
    $this->db->from("lab_packages");
    $this->db->where("main_data_id", $user_id);
    $this->db->where("status", 1);
    $this->db->where("delete_status", 1);
    $this->db->order_by("id", "desc");
    $this->db->limit($limit, $offset);
    $package_query = $this->db->get();
    $package_ids = array_column($package_query->result_array(), 'id');

    if (empty($package_ids)) {
        return []; // No packages found
    }

    // Step 2: Get all related tests and sub-tests
    $this->db->select("
        lab_packages.id AS package_id,
        lab_packages.name,
        lab_packages.image,
        lab_packages.one_person,
        lab_packages.one_person_discount,
        lab_packages.two_person,
        lab_packages.two_person_discount,
        lab_packages.three_person,
        lab_packages.three_person_discount,
        lab_packages.four_person,
        lab_packages.four_person_discount,
        lab_packages.five_person,
        lab_packages.five_person_discount,
        lab_packages.report_in,
        lab_packages.fasting,
        lab_package_tests.id AS test_id,
        lab_package_tests.name AS test_name,
        lab_sub_tests.id AS sub_test_id,
        lab_sub_tests.name AS sub_test_name,
        -- Combined test + subtest count as total_test_count
        (
            (SELECT COUNT(*) FROM lab_package_tests hdbt WHERE hdbt.package_id = lab_packages.id) +
            (SELECT COUNT(*) FROM lab_sub_tests hdbst WHERE hdbst.package_id = lab_packages.id)
        ) AS total_test_count
    ");
    $this->db->from('lab_packages');
    $this->db->join('lab_package_tests', 'lab_package_tests.package_id = lab_packages.id AND lab_package_tests.main_data_id = lab_packages.main_data_id AND lab_package_tests.status = 1 AND lab_package_tests.delete_status = 1', 'left');
    $this->db->join('lab_sub_tests', 'lab_sub_tests.test_id = lab_package_tests.id AND lab_sub_tests.package_id = lab_package_tests.package_id AND lab_sub_tests.main_data_id = lab_package_tests.main_data_id AND lab_sub_tests.status = 1 AND lab_sub_tests.delete_status = 1', 'left');
    $this->db->where_in('lab_packages.id', $package_ids);
    $this->db->where('lab_packages.main_data_id', $user_id);
    $this->db->where('lab_packages.status', 1);
    $this->db->where('lab_packages.delete_status', 1);
    $this->db->order_by('lab_packages.id', 'desc');

    $query = $this->db->get();
    $result = $query->result_array();

    // Step 3: Process data
    $final_data = [];

    foreach ($result as $row) {
        $package_id = $row['package_id'];
        $test_id = $row['test_id'];
        $sub_test_id = $row['sub_test_id'];

        if (!isset($final_data[$package_id])) {
            $final_data[$package_id] = [
                'id' => intval($package_id),
                'name' => $row['name'],
                'image' => $row['image'],
                'one_person' => intval($row['one_person']),
                'one_person_discount' => intval($row['one_person_discount']),
                'two_person' => intval($row['two_person']),
                'two_person_discount' => intval($row['two_person_discount']),
                'three_person' => intval($row['three_person']),
                'three_person_discount' => intval($row['three_person_discount']),
                'four_person' => intval($row['four_person']),
                'four_person_discount' => intval($row['four_person_discount']),
                'five_person' => intval($row['five_person']),
                'five_person_discount' => intval($row['five_person_discount']),
                'report_in' => $row['report_in'],
                'fasting' => $row['fasting'],
                'total_test_count' => intval($row['total_test_count']),
                'tests' => []
            ];
        }

        if ($test_id && !isset($final_data[$package_id]['tests'][$test_id])) {
            $final_data[$package_id]['tests'][$test_id] = [
                'id' => intval($test_id),
                'name' => $row['test_name'],
                'sub_tests' => []
            ];
        }

        if ($sub_test_id && isset($final_data[$package_id]['tests'][$test_id])) {
            $final_data[$package_id]['tests'][$test_id]['sub_tests'][] = [
                'id' => intval($sub_test_id),
                'name' => $row['sub_test_name']
            ];
        }
    }

    // Convert associative test arrays to indexed
    foreach ($final_data as &$package) {
        $package['tests'] = array_values($package['tests']);
    }

    return array_values($final_data);
}
public function get_lab_tests_rows($user_id){
    $this->db->from('lab_packages');
    $this->db->where(['main_data_id' => $user_id,'status' => 1,'delete_status' => 1]);
    return $this->db->count_all_results();
}
/*hamburger*/


}

?>