<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Ws_model extends CI_Model{

/*default functions*/
public function common_fetch($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','desc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_fetch_select($table, $where = [], $select = '*', $integerFields = []) {
    $this->db->select($select);
    $this->db->from($table);
    
    if (!empty($where)) {
        $this->db->where($where);
    }
    $this->db->order_by('id','desc');
    $query = $this->db->get();
    
    if ($query->num_rows() > 0) {
        $result = $query->result_array();
        
        // Type-cast requested fields to integer
        if (!empty($integerFields)) {
            foreach ($result as &$row) {
                foreach ($integerFields as $field) {
                    if (isset($row[$field])) {
                        $row[$field] = (int) $row[$field];
                    }
                }
            }
            unset($row);
        }
        
        return $result;
    } else {
        return [];
    }
}
public function common_fetch_asc($table,$where){
	$this->db->where($where);
	$this->db->order_by('id','asc');
	$query = $this->db->get($table);
	return $query->result_array();
}
public function common_insert($table,$data){	
	$this->db->insert($table,$data);
	$id = $this->db->insert_id();
	return $id;
}
public function common_update($table,$data,$where){
	$this->db->where($where);
	$this->db->update($table,$data);
}
public function common_delete($table,$where){
	$this->db->where($where);
	$this->db->delete($table);
}
public function common_fetch_rows($table,$where){
	$this->db->where($where);	
	$query = $this->db->get($table);
	return $query->num_rows();
}
// In your Ws_model.php
public function is_exists($table, $where = []) {
    $this->db->from($table);
    if (!empty($where)) {
        $this->db->where($where);
    }
    $query = $this->db->limit(1)->get();
    return $query->num_rows() > 0;
}
/*default functions*/

/*home_page*/
public function get_product_orders($user_id) {
    $this->db->select('pb.id, pb.booking_id, pb.created_on, pb.order_type, pb.booking_type,pb.accept_status, pbi.id AS product_id, pbi.name AS product_name, pbi.image');
    $this->db->from('pharmacy_product_bookings pb');
    $this->db->join('pharmacy_booked_products pbi', 'pbi.booking_id = pb.booking_id', 'left');
    //$this->db->join('pharmacy_products p', 'p.id = pbi.product_id', 'left');
    $this->db->where('pb.main_data_id', $user_id);
    $this->db->where('pb.booking_status', 'booked');

    // Add accept_status = 'accepted' OR accept_status = ''
    $this->db->group_start();
    $this->db->where('pb.accept_status', 'accepted');
    $this->db->or_where('pb.accept_status', '');
    $this->db->group_end();

    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'           => $row->id,
                'booking_id'   => $row->booking_id,
                'order_type'   => $row->order_type,
                'booking_type' => $row->booking_type,
                'accept_status'=> $row->accept_status,
                'created_on'   => $row->created_on,
                'products'     => []
            ];
        }
        $result[$id]['products'][] = [
            'product_name' => $row->product_name,
            'image'        => $row->image
        ];
    }

    return array_values($result);
}
public function get_prescription_orders($user_id){
    $this->db->select('id, booking_id, order_type, created_on,booking_type,image,accept_status');
    $this->db->from('pharmacy_medicine_orders');
    $this->db->where(['main_data_id' => $user_id,'booking_status' => 'booked']);
    // Add accept_status = 'accepted' OR accept_status = ''
    $this->db->group_start();
    $this->db->where('accept_status', 'accepted');
    $this->db->or_where('accept_status', '');
    $this->db->group_end();
    $this->db->order_by('created_on', 'DESC');

    $query = $this->db->get();
    $orders = $query->result();

    return $orders;
}
public function pharmacy_combined_orders($user_id, $limit, $offset){
    $product_orders = $this->get_product_orders($user_id);
    $prescription_orders = $this->get_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    usort($combined, function($a, $b) {
        return strtotime($b->created_on ?? $b['created_on']) - strtotime($a->created_on ?? $a['created_on']);
    });

    // Pagination manually
    $paged_orders = array_slice($combined, $offset, $limit);

    return [
        'orders' => $paged_orders,
        'total_orders' => count($combined),
        'limit' => $limit,
        'offset' => $offset
    ];
}
public function get_single_product_orders($booking_id){
    $this->db->select('pb.id,pb.booking_id, pb.created_on, pb.order_type, pb.user_id, pb.main_data_id, pb.cat_id, pb.address_id, pb.mobile, pb.name, pb.fee, pb.consultation_fee, pb.coupon_id,pb.coupon_name,pb.coupon_percentage,pb.coupon_discount,pb.payment_type,pb.booking_status,pb.order_type,pb.booking_type,pb.accept_status, pbi.id AS product_id, pbi.name AS product_name, pbi.image,u.image as user_image');
    $this->db->from('pharmacy_product_bookings pb');
    $this->db->join('pharmacy_booked_products pbi', 'pbi.booking_id = pb.booking_id', 'left');
    //$this->db->join('pharmacy_products p', 'p.id = pbi.product_id', 'left');
    $this->db->join('users u', 'u.id = pb.user_id', 'left');
    $this->db->where('pb.booking_id', $booking_id);
    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    // Group by booking ID to avoid duplication
    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'                => intval($row->id),
                'booking_id'        => $row->booking_id,
                'order_type'        => $row->order_type,
                'user_id'           => intval($row->user_id),
                'main_data_id'      => intval($row->main_data_id),
                'cat_id'            => intval($row->cat_id),
                'address_id'        => intval($row->address_id),
                'name'              => $row->name,
                'mobile'            => intval($row->mobile),
                'user_image'        => $row->user_image,
                'fee'               => intval($row->fee),
                'consultation_fee'  => intval($row->consultation_fee),
                'coupon_id'         => intval($row->coupon_id),
                'coupon_percentage' => intval($row->coupon_percentage),
                'coupon_discount'   => intval($row->coupon_discount),
                'payment_type'      => $row->payment_type,
                'order_type'        => $row->order_type,
                'booking_type'      => $row->booking_type,
                'booking_status'    => $row->booking_status,
                'accept_status'     => $row->accept_status,
                'created_on'        => $row->created_on,
                'products'          => []
            ];
        }
        $result[$id]['products'][] = [
            'product_name' => $row->product_name,
            'image' => $row->image
        ];
    }

    return array_values($result);
}
public function get_single_medicine_orders($booking_id){
    $this->db->select('pb.id,pb.booking_id, pb.created_on, pb.order_type, pb.user_id, pb.main_data_id, pb.address_id, pb.mobile, pb.name,pb.booking_status,pb.order_type,pb.booking_type, pb.accept_status,pb.image,u.image as user_image');
    $this->db->from('pharmacy_medicine_orders pb');
    $this->db->join('users u', 'u.id = pb.user_id', 'left');
    $this->db->where('pb.booking_id', $booking_id);
    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    // Group by booking ID to avoid duplication
    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'                => intval($row->id),
                'booking_id'        => $row->booking_id,
                'image'             => $row->image,
                'order_type'        => $row->order_type,
                'user_id'           => intval($row->user_id),
                'main_data_id'      => intval($row->main_data_id),
                'address_id'        => intval($row->address_id),
                'name'              => $row->name,
                'mobile'            => intval($row->mobile),
                'user_image'        => $row->user_image,
                'booking_type'      => $row->booking_type,
                'booking_status'    => $row->booking_status,
                'accept_status'     => $row->accept_status,
                'created_on'        => $row->created_on
            ];
        }
    }

    return array_values($result);
}
/*home_page*/

/*hamburger*/
public function get_pharmacy_products($user_id, $cat_id, $limit, $offset) {
    $this->db->select('
        pp.id,
        pp.main_data_id,
        pp.cat_id,
        pp.name,
        pp.image,
        pp.price,
        pp.discount_price
    ');
    $this->db->from('pharmacy_products pp');
    $this->db->where([
        'pp.main_data_id' => $user_id,
        'pp.cat_id'       => $cat_id,
        'pp.status'       => 1,
        'pp.delete_status'=> 1
    ]);
    $this->db->order_by('pp.id', 'desc');
    $this->db->limit($limit, $offset);

    $query = $this->db->get();
    $result = $query->result_array();

    return array_map(function ($row) {
        return [
            'id'             => intval($row['id']),
            'main_data_id'   => intval($row['main_data_id']),
            'cat_id'         => intval($row['cat_id']),
            'name'           => $row['name'],
            'image'          => $row['image'],
            'price'          => intval($row['price']),
            'discount_price' => intval($row['discount_price'])
        ];
    }, $result);
}
public function get_pharmacy_products_rows($user_id,$cat_id){
    $this->db->where(['main_data_id' => $user_id,'cat_id' => $cat_id,'status' => 1,'delete_status' => 1]);
    $this->db->order_by('id','desc');
    $query = $this->db->get('pharmacy_products');
    $result = $query->num_rows();
    return $result;
}
public function get_completed_product_orders($user_id) {
    $this->db->select('pb.id, pb.booking_id, pb.created_on, pb.order_type, pb.booking_type,pb.accept_status, pbi.id AS product_id, pbi.name AS product_name, pbi.image');
    $this->db->from('pharmacy_product_bookings pb');
    $this->db->join('pharmacy_booked_products pbi', 'pbi.booking_id = pb.booking_id', 'left');
    //$this->db->join('pharmacy_products p', 'p.id = pbi.product_id', 'left');
    $this->db->where('pb.main_data_id', $user_id);
    $this->db->where('pb.booking_status', 'completed');

    $this->db->order_by('pb.created_on', 'DESC');

    $query = $this->db->get();
    $raw = $query->result();

    $result = [];
    foreach ($raw as $row) {
        $id = $row->booking_id;
        if (!isset($result[$id])) {
            $result[$id] = [
                'id'           => $row->id,
                'booking_id'   => $row->booking_id,
                'order_type'   => $row->order_type,
                'booking_type' => $row->booking_type,
                'accept_status'=> $row->accept_status,
                'created_on'   => $row->created_on,
                'products'     => []
            ];
        }
        $result[$id]['products'][] = [
            'product_name' => $row->product_name,
            'image'        => $row->image
        ];
    }

    return array_values($result);
}
public function get_completed_prescription_orders($user_id){
    $this->db->select('id, booking_id, order_type, created_on,booking_type,image,accept_status');
    $this->db->from('pharmacy_medicine_orders');
    $this->db->where(['main_data_id' => $user_id,'booking_status' => 'completed']);
    $this->db->order_by('created_on', 'DESC');

    $query = $this->db->get();
    $orders = $query->result();

    return $orders;
}
public function pharmacy_completed_combined_orders($user_id, $limit, $offset){
    $product_orders = $this->get_completed_product_orders($user_id);
    $prescription_orders = $this->get_completed_prescription_orders($user_id);

    // Merge and sort by created_on
    $combined = array_merge($product_orders, $prescription_orders);

    usort($combined, function($a, $b) {
        return strtotime($b->created_on ?? $b['created_on']) - strtotime($a->created_on ?? $a['created_on']);
    });

    // Pagination manually
    $paged_orders = array_slice($combined, $offset, $limit);

    return [
        'orders' => $paged_orders,
        'total_orders' => count($combined),
        'limit' => $limit,
        'offset' => $offset
    ];
}
public function get_pharmacy_main_data($user_id) {
    $this->db->select("
        pharmacies.*, 
        GROUP_CONCAT(DISTINCT img.image) AS images
    ", false); 
    
    $this->db->from('pharmacies');
    
    // Join images table
    $this->db->join('pharmacy_images img', 'img.main_data_id = pharmacies.id AND img.status=1 AND img.delete_status=1', 'left');

    // Filters
    $this->db->where('pharmacies.id', $user_id);


    // Grouping & Sorting
    $this->db->group_by('pharmacies.id');

    $query = $this->db->get();
    $result = $query->result_array();

    // Process the results using array_map
    return array_map(function ($row) {
        return [
            'id'                => intval($row['id']),
            'name'              => $row['name'],
            'mobile'            => intval($row['mobile']),
            'logo'              => $row['logo'],
            'open_time'         => $row['open_time'],
            'close_time'        => $row['close_time'],
            'location'          => $row['location'],
            'description'       => $row['description'],
            'lat'               => $row['lat'],
            'lon'               => $row['lon'],
            'home_delivery'     => $row['home_delivery'],
            'images'      => (!empty($row['images']) && is_string($row['images']))
                ? array_map(function ($image) {
                    return ['url' => trim($image)];
                }, array_filter(explode(',', $row['images'])))
                : []
        ];
    }, $result);
}
/*hamburger*/

}

?>